<?php
/**
 * Elementor oEmbed Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */

use Elementor\Modules\DynamicTags\Module as TagsModule;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Border;

class Tf_Youtube_Widgets extends \Elementor\Widget_Base
{

  /**
   * Get widget name.
   *
   * Retrieve oEmbed widget name.
   *
   * @since 1.0.0
   * @access public
   *
   * @return string Widget name.
   */
  public function get_name()
  {
    return 'tfyoutube';
  }

  /**
   * Get widget title.
   *
   * Retrieve oEmbed widget title.
   *
   * @since 1.0.0
   * @access public
   *
   * @return string Widget title.
   */
  public function get_title()
  {
    return esc_html__('TF Youtube', 'plugin-name');
  }

  /**
   * Get widget icon.
   *
   * Retrieve oEmbed widget icon.
   *
   * @since 1.0.0
   * @access public
   *
   * @return string Widget icon.
   */
  public function get_icon()
  {
    return 'eicon-youtube';
  }

  /**
   * Get widget categories.
   *
   * Retrieve the list of categories the oEmbed widget belongs to.
   *
   * @since 1.0.0
   * @access public
   *
   * @return array Widget categories.
   */
  public function get_categories()
  {
    return ['themesflat_addons'];
  }

  /**
   * Register oEmbed widget controls.
   *
   * Adds different input fields to allow the user to change and customize the widget settings.
   *
   * @since 1.0.0
   * @access protected
   */
  protected function register_controls()
  {
    $this->ytAPI();
    $this->ytInfo();
    $this->ytSetting();
    $this->ytStyle();
  }

  function ytStyle()
  {
    $this->start_controls_section(
      'section_item_title_styling',
      [
        'label' => esc_html__('Video Title', 'fel'),
        'tab' => Controls_Manager::TAB_STYLE,
      ]
    );

    $this->add_control(
      'item_title_tag',
      [
        'label' => esc_html__('Title HTML Tag', 'fel'),
        'type' => Controls_Manager::SELECT,
        'options' => [
          'h1' => esc_html__('H1', 'fel'),
          'h2' => esc_html__('H2', 'fel'),
          'h3' => esc_html__('H3', 'fel'),
          'h4' => esc_html__('H4', 'fel'),
          'h5' => esc_html__('H5', 'fel'),
          'h6' => esc_html__('H6', 'fel'),
          'div' => esc_html__('div', 'fel'),
        ],
        'default' => 'h3',
      ]
    );

    $this->add_control(
      'item_title_color',
      [
        'label' => esc_html__('Title Color', 'fel'),
        'type' => Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .fel-ytTitle' => 'color: {{VALUE}};',
          '{{WRAPPER}} .fel-ytTitle a' => 'color: {{VALUE}};',
        ],
      ]
    );

    $this->add_control(
      'title_hover_color',
      [
        'label' => esc_html__('Title Hover Color', 'fel'),
        'type' => Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .fel-ytTitle:hover' => 'text-decoration: none; color: {{VALUE}};',
          '{{WRAPPER}} .fel-ytTitle a:hover' => 'text-decoration: none; color: {{VALUE}};',
        ],
      ]
    );

    $this->add_control(
      'title_height',
      [
        'label' => esc_html__('Max Height', 'fel'),
        'type' => Controls_Manager::SLIDER,
        'size_units' => ['px'],
        'range' => [
          'px' => [
            'min' => 12,
            'max' => 100,
          ],
        ],
        'default' => [
          'size' => 50,
        ],
        'selectors' => [
          '{{WRAPPER}} .fel-ytWrap__content .fel-ytWrap__item__info .fel-ytTitle' => 'max-height: {{SIZE}}{{UNIT}};',
        ],
      ]
    );

    $this->add_control(
      'title_row',
      [
        'label' => esc_html__('Multi Rows', 'fel'),
        'type' => Controls_Manager::SLIDER,
        'size_units' => [],
        'range' => [
          'min' => 1,
          'max' => 10,
        ],
        'default' => [
          'size' => 2,
        ],
        'selectors' => [
          '{{WRAPPER}} .fel-ytWrap__content .fel-ytWrap__item__info .fel-ytTitle' => '-webkit-line-clamp: {{SIZE}};',
        ],
      ]
    );

    $this->add_control(
      'title_margin',
      [
        'label' => esc_html__('Distant', 'fel'),
        'type' => Controls_Manager::DIMENSIONS,
        'size_units' => ['px', '%', 'em'],
        'selectors' => [
          '{{WRAPPER}} .fel-ytWrap__content .fel-ytWrap__item__info .fel-ytTitle' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
      ]
    );

    $this->add_group_control(
      Group_Control_Typography::get_type(),
      [
        'name' => 'item_title_typography',
        'selector' => '{{WRAPPER}} #{{item_title_tag.VALUE}} a',
      ]
    );


    $this->end_controls_section();

    $this->start_controls_section(
      'section_item_text_styling',
      [
        'label' => esc_html__('Video Excerpt', 'fel'),
        'tab' => Controls_Manager::TAB_STYLE,
        'condition' => [
          'display_excerpt' => ['yes']
        ],
      ]
    );

    $this->add_control(
      'item_text_color',
      [
        'label' => esc_html__('Text Color', 'fel'),
        'type' => Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .fel-ytWrap__item__info p' => 'color: {{VALUE}};',
        ],
      ]
    );

    $this->add_control(
      'item_text_link_color',
      [
        'label' => esc_html__('Text Link Color', 'fel'),
        'type' => Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .fel-ytWrap__item__info p a' => 'color: {{VALUE}};',
        ],
      ]
    );

    $this->add_control(
      'item_text_link_hover_color',
      [
        'label' => esc_html__('Text Link Hover Color', 'fel'),
        'type' => Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .fel-ytWrap__item__info p a:hover' => 'color: {{VALUE}};',
        ],
      ]
    );

    $this->add_control(
      'item_text_height',
      [
        'label' => esc_html__('Max Height', 'fel'),
        'type' => Controls_Manager::SLIDER,
        'size_units' => ['px'],
        'range' => [
          'px' => [
            'min' => 1,
            'max' => 1000,
          ],
        ],
        'default' => [
          'size' => 150,
        ],
        'selectors' => [
          '{{WRAPPER}} .fel-ytWrap__item__info p' => 'max-height: {{SIZE}}{{UNIT}};',
        ],
      ]
    );

    $this->add_control(
      'item_text_row',
      [
        'label' => esc_html__('Multi Rows', 'fel'),
        'type' => Controls_Manager::SLIDER,
        'size_units' => [],
        'range' => [
          'min' => 1,
          'max' => 100,
        ],
        'default' => [
          'size' => 5,
        ],
        'selectors' => [
          '{{WRAPPER}} .fel-ytWrap__item__info p' => '-webkit-line-clamp: {{SIZE}};',
        ],
      ]
    );

    $this->add_control(
      'item_text_margin',
      [
        'label' => esc_html__('Distant', 'fel'),
        'type' => Controls_Manager::DIMENSIONS,
        'size_units' => ['px', '%', 'em'],
        'selectors' => [
          '{{WRAPPER}} .fel-ytWrap__item__info p' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
      ]
    );

    $this->add_group_control(
      Group_Control_Typography::get_type(),
      [
        'name' => 'item_text_typography',
        'selector' => '{{WRAPPER}} .fel-ytWrap__item__info p',
      ]
    );


    $this->end_controls_section();

    $this->start_controls_section(
      'section_entry_channel_name_styling',
      [
        'label' => esc_html__('Channel Name', 'fel'),
        'tab' => Controls_Manager::TAB_STYLE,
      ]
    );

    $this->add_control(
      'channel_name_margin',
      [
        'label' => esc_html__('Distant', 'fel'),
        'type' => Controls_Manager::DIMENSIONS,
        'size_units' => ['px', '%', 'em'],
        'selectors' => [
          '{{WRAPPER}} .fel-ytWrap__headTab span' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
        'condition' => [
          'layout_grid' => ['slider1', 'slider2', 'tab'],
          'layout_videos_nav' => ['yes']
        ],
      ]
    );

    $this->add_control(
      'channel_name_color',
      [
        'label' => esc_html__('Color', 'fel'),
        'type' => Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .fel-ytWrap__avarta span' => 'color: {{VALUE}};',
          '{{WRAPPER}} .fel-ytWrap__headTab span' => 'color: {{VALUE}};',
        ],
      ]
    );

    $this->add_control(
      'channel_name_color_hover',
      [
        'label' => esc_html__('Color Hover', 'fel'),
        'type' => Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .fel-ytWrap__headTab span:hover' => 'color: {{VALUE}};',
        ],
        'condition' => [
          'layout_grid' => ['slider1', 'slider2', 'tab'],
          'layout_videos_nav' => ['yes']
        ],
      ]
    );

    $this->add_group_control(
      Group_Control_Background::get_type(),
      [
        'name' => 'channel_name_backgound',
        'label' => esc_attr__('Background', 'fel'),
        'types' => ['classic', 'gradient'],
        'selector' => '{{WRAPPER}} .fel-ytWrap__headTab span',
        'condition' => [
          'layout_grid' => ['slider1', 'slider2', 'tab'],
          'layout_videos_nav' => ['yes']
        ],
      ]
    );

    $this->add_group_control(
      Group_Control_Background::get_type(),
      [
        'name' => 'channel_name_backgound_hover',
        'label' => esc_attr__('Background hover', 'fel'),
        'types' => ['classic', 'gradient'],
        'selector' => '{{WRAPPER}} .fel-ytWrap__headTab span:hover',
        'condition' => [
          'layout_grid' => ['slider1', 'slider2', 'tab'],
          'layout_videos_nav' => ['yes']
        ],
      ]
    );

    $this->add_control(
      'channel_name_padding',
      [
        'label' => esc_html__('Padding', 'fel'),
        'type' => Controls_Manager::DIMENSIONS,
        'size_units' => ['px', '%', 'em'],
        'selectors' => [
          '{{WRAPPER}} .fel-ytWrap__headTab span' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ], 'condition' => [
        'layout_grid' => ['slider1', 'slider2', 'tab'],
        'layout_videos_nav' => ['yes']
      ],
      ]
    );

    $this->add_control(
      'channel_name_border_size',
      [
        'label' => esc_html__('Border Size', 'fel'),
        'type' => Controls_Manager::DIMENSIONS,
        'size_units' => ['px', '%', 'em'],
        'selectors' => [
          '{{WRAPPER}} .fel-ytWrap__headTab span' => 'border-width: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ], 'condition' => [
        'layout_grid' => ['slider1', 'slider2', 'tab'],
        'layout_videos_nav' => ['yes']
      ],
      ]
    );

    $this->add_control(
      'style_border_head_tab',
      [
        'label' => esc_attr__('Border head tab', 'fel'),
        'type' => Controls_Manager::HEADING,
        'condition' => [
          'layout_grid' => ['slider1', 'slider2', 'tab'],
          'layout_videos_nav' => ['yes']
        ],
      ]
    );

    $this->add_group_control(
      Group_Control_Border::get_type(),
      [
        'name' => 'channel_name_border_color',
        'label' => esc_attr__('Border Color', 'fel'),
        'types' => ['classic', 'gradient'],
        'selector' => '{{WRAPPER}} .fel-ytWrap__headTab span',
        'condition' => [
          'layout_grid' => ['slider1', 'slider2', 'tab'],
          'layout_videos_nav' => ['yes']
        ],
      ]
    );

    $this->add_control(
      'style_border_head_tab_active',
      [
        'label' => esc_attr__('Border head active', 'fel'),
        'type' => Controls_Manager::HEADING,
        'condition' => [
          'layout_grid' => ['slider1', 'slider2', 'tab'],
          'layout_videos_nav' => ['yes']
        ],
      ]
    );

    $this->add_group_control(
      Group_Control_Border::get_type(),
      [
        'name' => 'channel_name_border_color_active',
        'label' => esc_attr__('Border Color Active', 'fel'),
        'types' => ['classic', 'gradient'],
        'selector' => '{{WRAPPER}} .fel-ytWrap__headTab span.active',
        'condition' => [
          'layout_grid' => ['slider1', 'slider2', 'tab'],
          'layout_videos_nav' => ['yes']
        ],
      ]
    );

    $this->add_control(
      'style_border_head_tab_hover',
      [
        'label' => esc_attr__('Border head hover', 'fel'),
        'type' => Controls_Manager::HEADING,
        'condition' => [
          'layout_grid' => ['slider1', 'slider2', 'tab'],
          'layout_videos_nav' => ['yes']
        ],
      ]
    );

    $this->add_group_control(
      Group_Control_Border::get_type(),
      [
        'name' => 'channel_name_border_color_hover',
        'label' => esc_attr__('Border Color Hover', 'fel'),
        'types' => ['classic', 'gradient'],
        'selector' => '{{WRAPPER}} .fel-ytWrap__headTab span:hover',
        'condition' => [
          'layout_grid' => ['slider1', 'slider2', 'tab'],
          'layout_videos_nav' => ['yes']
        ],
      ]
    );

    $this->add_responsive_control(
      'channel_name_radius_size',
      [
        'label' => esc_html__('Border radius', 'fel'),
        'type' => Controls_Manager::DIMENSIONS,
        'default' => [
          'top' => '',
          'right' => '',
          'bottom' => '',
          'left' => '',
        ],
        'range' => [
          'px' => [
            'min' => 0,
            'max' => 1000,
          ],
        ],
        'selectors' => [
          '{{WRAPPER}}  .fel-ytWrap__headTab span' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ], 'condition' => [
        'layout_grid' => ['slider1', 'slider2', 'tab'],
        'layout_videos_nav' => ['yes']
      ],
      ]
    );

    $this->add_group_control(
      Group_Control_Typography::get_type(),
      [
        'name' => 'channel_name_typography',
        'selector' => '{{WRAPPER}} .fel-ytWrap__avarta span',
      ]
    );

    $this->end_controls_section();

    $this->start_controls_section(
      'section_entry_date_styling',
      [
        'label' => esc_html__('Posted Date', 'fel'),
        'tab' => Controls_Manager::TAB_STYLE,
      ]
    );

    $this->add_control(
      'entry_date_color',
      [
        'label' => esc_html__('Posted Date Color', 'fel'),
        'type' => Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .fel-ytWrap__date' => 'color: {{VALUE}};',
        ],
      ]
    );

    $this->add_control(
      'entry_date_width',
      [
        'label' => esc_html__('Posted Date Width', 'fel'),
        'type' => Controls_Manager::SLIDER,
        'size_units' => ['px'],
        'range' => [
          'px' => [
            'min' => 12,
            'max' => 200,
          ],
        ],
        'default' => [
          'size' => 65,
        ],
        'selectors' => [
          '{{WRAPPER}} .fel-ytWrap__date' => 'width: {{SIZE}}{{UNIT}};',
        ],
      ]
    );

    $this->add_group_control(
      Group_Control_Typography::get_type(),
      [
        'name' => 'entry_date_typography',
        'selector' => '{{WRAPPER}} .fel-ytWrap__date',
      ]
    );

    $this->end_controls_section();

    $this->start_controls_section(
      'section_entry_views_styling',
      [
        'label' => esc_html__('Views', 'fel'),
        'tab' => Controls_Manager::TAB_STYLE,
      ]
    );

    $this->add_control(
      'entry_views_size',
      [
        'label' => esc_html__('Views size in pixels', 'fel'),
        'type' => Controls_Manager::SLIDER,
        'size_units' => ['px'],
        'range' => [
          'px' => [
            'min' => 12,
            'max' => 96,
          ],
        ],
        'default' => [
          'size' => 14,
        ],
        'selectors' => [
          '{{WRAPPER}} .fel-ytWrap__details .fel-ytWrap__views' => 'font-size: {{SIZE}}{{UNIT}};',
        ],
      ]
    );

    $this->add_control(
      'entry_views_icon_color',
      [
        'label' => esc_html__('Views Icon Color', 'fel'),
        'type' => Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .fel-ytWrap__details .fel-ytWrap__views i' => 'color: {{VALUE}};',
        ],
      ]
    );

    $this->add_control(
      'entry_views_color',
      [
        'label' => esc_html__('Views Count Color', 'fel'),
        'type' => Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .fel-ytWrap__details .fel-ytWrap__views' => 'color: {{VALUE}};',
        ],
      ]
    );

    $this->add_group_control(
      Group_Control_Typography::get_type(),
      [
        'name' => 'entry_views_typography',
        'selector' => '{{WRAPPER}} .fel-ytWrap__details .fel-ytWrap__views',
      ]
    );

    $this->end_controls_section();

    $this->start_controls_section(
      'section_entry_likes_styling',
      [
        'label' => esc_html__('Likes', 'fel'),
        'tab' => Controls_Manager::TAB_STYLE,
      ]
    );

    $this->add_control(
      'entry_likes_size',
      [
        'label' => esc_html__('Likes Icon size in pixels', 'fel'),
        'type' => Controls_Manager::SLIDER,
        'size_units' => ['px'],
        'range' => [
          'px' => [
            'min' => 12,
            'max' => 96,
          ],
        ],
        'default' => [
          'size' => 14,
        ],
        'selectors' => [
          '{{WRAPPER}} .fel-ytWrap__details .fel-ytWrap__like' => 'font-size: {{SIZE}}{{UNIT}};',
        ],
      ]
    );

    $this->add_control(
      'entry_likes_icon_color',
      [
        'label' => esc_html__('Likes Icon Color', 'fel'),
        'type' => Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .fel-ytWrap__details .fel-ytWrap__like i' => 'color: {{VALUE}};',
        ],
      ]
    );

    $this->add_control(
      'entry_likes_color',
      [
        'label' => esc_html__('Likes Color', 'fel'),
        'type' => Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .fel-ytWrap__details .fel-ytWrap__like' => 'color: {{VALUE}};',
        ],
      ]
    );

    $this->add_group_control(
      Group_Control_Typography::get_type(),
      [
        'name' => 'entry_likes_typography',
        'selector' => '{{WRAPPER}} .lae-block-youtube-grid .lae-module .lae-module-details .lae-entry-likes',
      ]
    );

    $this->end_controls_section();

    $this->start_controls_section(
      'section_entry_comments_styling',
      [
        'label' => esc_html__('Comments', 'fel'),
        'tab' => Controls_Manager::TAB_STYLE,
      ]
    );

    $this->add_control(
      'entry_comments_size',
      [
        'label' => esc_html__('Comments Icon size in pixels', 'fel'),
        'type' => Controls_Manager::SLIDER,
        'size_units' => ['px'],
        'range' => [
          'px' => [
            'min' => 12,
            'max' => 96,
          ],
        ],
        'default' => [
          'size' => 14,
        ],
        'selectors' => [
          '{{WRAPPER}} .fel-ytWrap__details .fel-ytWrap__comments' => 'font-size: {{SIZE}}{{UNIT}};',
        ],
      ]
    );

    $this->add_control(
      'entry_comments_icon_color',
      [
        'label' => esc_html__('Comments Icon Color', 'fel'),
        'type' => Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .fel-ytWrap__details .fel-ytWrap__comments i' => 'color: {{VALUE}};',
        ],
      ]
    );

    $this->add_control(
      'entry_comments_color',
      [
        'label' => esc_html__('Comments Color', 'fel'),
        'type' => Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .fel-ytWrap__details .fel-ytWrap__comments' => 'color: {{VALUE}};',
        ],
      ]
    );

    $this->add_group_control(
      Group_Control_Typography::get_type(),
      [
        'name' => 'entry_comments_typography',
        'selector' => '{{WRAPPER}} .fel-ytWrap__details .fel-ytWrap__comments',
      ]
    );

    $this->end_controls_section();

    $this->start_controls_section(
      'section_entry_duration_styling',
      [
        'label' => esc_html__('Duration', 'fel'),
        'tab' => Controls_Manager::TAB_STYLE,
      ]
    );

    $this->add_control(
      'entry_duration_bg_color',
      [
        'label' => esc_html__('Duration Background Color', 'fel'),
        'type' => Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .fel-ytWrap__time' => 'background-color: {{VALUE}};',
        ],
      ]
    );

    $this->add_control(
      'entry_duration_color',
      [
        'label' => esc_html__('Duration Color', 'fel'),
        'type' => Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .fel-ytWrap__time' => 'color: {{VALUE}};',
        ],
      ]
    );

    $this->add_group_control(
      Group_Control_Typography::get_type(),
      [
        'name' => 'entry_duration_typography',
        'selector' => '{{WRAPPER}} .fel-ytWrap__time',
      ]
    );

    $this->end_controls_section();

    $this->start_controls_section(
      'section_load_more_button_styling',
      [
        'label' => esc_html__('Load More Button', 'fel'),
        'tab' => Controls_Manager::TAB_STYLE
      ]
    );

    $this->add_control(
      'load_more_button_custom_color',
      [
        'label' => esc_html__('Button Color', 'fel'),
        'type' => Controls_Manager::COLOR,
        'default' => '',
        'selectors' => [
          '{{WRAPPER}} .fel-ytLoadMore' => 'background-color: {{VALUE}}; border-color: {{VALUE}};',
        ],
      ]
    );

    $this->add_control(
      'load_more_button_custom_hover_color',
      [
        'label' => esc_html__('Button Hover Color', 'fel'),
        'type' => Controls_Manager::COLOR,
        'default' => '',
        'selectors' => [
          '{{WRAPPER}} .fel-ytLoadMore:hover' => 'background-color: {{VALUE}}; border-color: {{VALUE}};',
        ],
      ]
    );

    $this->add_control(
      'load_more_button_padding',
      [
        'label' => esc_html__('Custom Padding', 'fel'),
        'type' => Controls_Manager::DIMENSIONS,
        'size_units' => ['px', '%', 'em'],
        'selectors' => [
          '{{WRAPPER}} .fel-ytLoadMore' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
        'isLinked' => false
      ]
    );

    $this->add_control(
      'load_more_button_border_radius',
      [
        'label' => esc_html__('Custom Border Radius', 'fel'),
        'type' => Controls_Manager::DIMENSIONS,
        'size_units' => ['px', '%', 'em'],
        'selectors' => [
          '{{WRAPPER}} .fel-ytLoadMore' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
      ]
    );

    $this->add_control(
      'load_more_button_label_color',
      [
        'label' => esc_html__('Label Color', 'fel'),
        'type' => Controls_Manager::COLOR,
        'default' => '',
        'selectors' => [
          '{{WRAPPER}} .fel-ytLoadMore' => 'color: {{VALUE}};',
        ],
      ]
    );

    $this->add_control(
      'load_more_button_label_hover_color',
      [
        'label' => esc_html__('Label Hover Color', 'fel'),
        'type' => Controls_Manager::COLOR,
        'default' => '',
        'selectors' => [
          '{{WRAPPER}} .fel-ytLoadMore:hover' => 'color: {{VALUE}};',
        ],
      ]
    );

    $this->add_group_control(
      Group_Control_Typography::get_type(),
      [
        'name' => 'load_more_button_typography',
        'label' => esc_html__('Typography', 'fel'),
        'selector' => '{{WRAPPER}} .fel-ytLoadMore',
      ]
    );

    $this->end_controls_section();

    $this->start_controls_section(
      'section_banner_channel_name_styling',
      [
        'label' => esc_html__('Banner Channel Name', 'fel'),
        'tab' => Controls_Manager::TAB_STYLE,
      ]
    );

    $this->add_control(
      'banner_channel_name_color',
      [
        'label' => esc_html__('Channel Name Color', 'fel'),
        'type' => Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .fel-ytWrap__detail .fel-ytWrap__info h3 a' => 'color: {{VALUE}};',
        ],
      ]
    );

    $this->add_control(
      'banner_channel_name_link_hover_color',
      [
        'label' => esc_html__('Channel Name Link Hover Color', 'fel'),
        'type' => Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .fel-ytWrap__detail .fel-ytWrap__info h3 a:hover' => 'color: {{VALUE}};',
        ],
      ]
    );

    $this->add_group_control(
      Group_Control_Typography::get_type(),
      [
        'name' => 'banner_channel_name_typography',
        'selector' => '{{WRAPPER}} .fel-ytWrap__detail .fel-ytWrap__info h3 a',
      ]
    );

    $this->end_controls_section();

    $this->start_controls_section(
      'section_channel_stats_styling',
      [
        'label' => esc_html__('Channel Stats', 'fel'),
        'tab' => Controls_Manager::TAB_STYLE,
      ]
    );

    $this->add_control(
      'channel_stats_color',
      [
        'label' => esc_html__('Channel Stats Color', 'fel'),
        'type' => Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .fel-ytWrap__stats' => 'color: {{VALUE}};',
        ],
      ]
    );

    $this->add_group_control(
      Group_Control_Typography::get_type(),
      [
        'name' => 'channel_stats_typography',
        'selector' => '{{WRAPPER}} .fel-ytWrap__stats',
      ]
    );

    $this->end_controls_section();

    $this->start_controls_section(
      'section_channel_desc_styling',
      [
        'label' => esc_html__('Channel Description', 'fel'),
        'tab' => Controls_Manager::TAB_STYLE,
      ]
    );

    $this->add_control(
      'channel_desc_color',
      [
        'label' => esc_html__('Text Color', 'fel'),
        'type' => Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .fel-ytWrap__detail p' => 'color: {{VALUE}};',
        ],
      ]
    );

    $this->add_group_control(
      Group_Control_Typography::get_type(),
      [
        'name' => 'channel_desc_typography',
        'selector' => '{{WRAPPER}} .fel-ytWrap__detail p',
      ]
    );

    $this->end_controls_section();

    $this->start_controls_section(
      'style_preloader',
      [
        'label' => esc_html__('Preloader', 'fel'),
        'tab' => Controls_Manager::TAB_STYLE,
      ]
    );

    $this->add_control(
      'style_preloader_bottom',
      [
        'label' => esc_html__('Distant with button Load More', 'fel'),
        'type' => Controls_Manager::SLIDER,
        'size_units' => ['px'],
        'range' => [
          'px' => [
            'min' => 0,
            'max' => 1000,
          ],
        ],
        'default' => [
          'size' => 50,
        ],
        'selectors' => [
          '{{WRAPPER}} .fel-ytLoader > [class*="fel-ytLoader"]' => 'bottom: {{SIZE}}{{UNIT}};',
        ],
      ]
    );

    $this->ytLoader1();
    $this->ytLoader2();
    $this->ytLoader3();
    $this->ytLoader4();
    $this->ytLoader5();
    $this->ytLoader6();
    $this->ytLoader7();
    $this->ytLoader8();
    $this->ytLoader9();
    $this->ytLoader10();
    $this->ytLoader11();
    $this->ytLoader12();
    $this->ytLoader13();
    $this->ytLoader14();
    $this->ytLoader15();

    $this->end_controls_section();

    $this->start_controls_section(
      'style_tabContent',
      [
        'label' => esc_html__('Tab Content', 'fel'),
        'tab' => Controls_Manager::TAB_STYLE,
        'condition' => [
          'layout_grid' => ['tab']
        ],
      ]
    );

    $this->add_control(
      'style_tab_border',
      [
        'label' => esc_attr__('Background', 'fel'),
        'type' => Controls_Manager::HEADING,
        'condition' => [
          'layout_grid' => ['tab']
        ],
      ]
    );


    $this->add_group_control(
      Group_Control_Border::get_type(),
      [
        'name' => 'size_tab_border',
        'label' => esc_attr__('Border', 'fel'),
        'types' => ['classic', 'gradient'],
        'selector' =>
          '{{WRAPPER}} .fel-ytWrap__tabContent',
        'condition' => [
          'layout_grid' => ['tab'],
        ],
      ]
    );

    $this->add_group_control(
      Group_Control_Background::get_type(),
      [
        'name' => 'bg_tab_content',
        'label' => esc_attr__('Background', 'fel'),
        'types' => ['classic', 'gradient'],
        'selector' => '{{WRAPPER}} .fel-ytWrap__tabContent',
        'condition' => [
          'layout_grid' => ['tab'],
        ],
      ]
    );

    $this->end_controls_section();
  }

  function ytLoader1()
  {
    $this->add_control(
      'style_preloader1_size',
      [
        'label' => esc_html__('Size Loader', 'fel'),
        'type' => Controls_Manager::SLIDER,
        'size_units' => ['px'],
        'range' => [
          'px' => [
            'min' => 0,
            'max' => 1000,
          ],
        ],
        'default' => [
          'size' => 30,
        ],
        'selectors' => [
          '{{WRAPPER}} .fel-ytLoader1' => 'width: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}};',
        ],
        'condition' => [
          'setting_preloader' => 'style1'
        ],
      ]
    );

    $this->add_group_control(
      \Elementor\Group_Control_Box_Shadow::get_type(),
      [
        'name' => 'style_preloader1_shadow',
        'label' => esc_html__('Box Shadow', 'fel'),
        'selector' => '{{WRAPPER}} .fel-ytLoader1',
        'condition' => [
          'setting_preloader' => 'style1'
        ],
      ]
    );

    $this->add_control(
      'style_preloader1_bgc1',
      [
        'label' => esc_html__('Background Color 1', 'fel'),
        'type' => Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .fel-ytLoader1:before' => 'background-color: {{VALUE}};',
        ],
        'condition' => [
          'setting_preloader' => 'style1'
        ],
      ]
    );

    $this->add_control(
      'style_preloader1_bgc2',
      [
        'label' => esc_html__('Background Color 2', 'fel'),
        'type' => Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .fel-ytLoader1:after' => 'background-color: {{VALUE}};',
        ],
        'condition' => [
          'setting_preloader' => 'style1'
        ],
      ]
    );
  }

  function ytLoader2()
  {
    $this->add_control(
      'style_preloader2_bgc1',
      [
        'label' => esc_html__('Background Color 1', 'fel'),
        'type' => Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .fel-ytLoader2 span' => 'background-color: {{VALUE}};',
        ],
        'condition' => [
          'setting_preloader' => 'style2'
        ],
      ]
    );

    $this->add_control(
      'style_preloader2_bgc2',
      [
        'label' => esc_html__('Background Color 2', 'fel'),
        'type' => Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .fel-ytLoader2 span:before' => 'background-color: {{VALUE}};',
        ],
        'condition' => [
          'setting_preloader' => 'style2'
        ],
      ]
    );
  }

  function ytLoader3()
  {
    $this->add_control(
      'style_preloader3_size',
      [
        'label' => esc_html__('Size Loader', 'fel'),
        'type' => Controls_Manager::SLIDER,
        'size_units' => ['px'],
        'range' => [
          'px' => [
            'min' => 0,
            'max' => 50,
          ],
        ],
        'default' => [
          'size' => 15,
        ],
        'selectors' => [
          '{{WRAPPER}} .fel-ytLoader3 .dot' => 'width: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}};',
        ],
        'condition' => [
          'setting_preloader' => 'style3'
        ],
      ]
    );

    $this->add_control(
      'style_preloader3_margin',
      [
        'label' => esc_html__('Margin', 'fel'),
        'type' => Controls_Manager::DIMENSIONS,
        'size_units' => ['px'],
        'selectors' => [
          '{{WRAPPER}} .fel-ytLoader3 .dot' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
        'condition' => [
          'setting_preloader' => 'style3'
        ],
      ]
    );

    $this->add_control(
      'style_preloader3_bgc1',
      [
        'label' => esc_html__('Background Color 1', 'fel'),
        'type' => Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .fel-ytLoader3 .dot:nth-child(1)' => 'background-color: {{VALUE}};',
        ],
        'condition' => [
          'setting_preloader' => 'style3'
        ],
      ]
    );

    $this->add_control(
      'style_preloader3_bgc2',
      [
        'label' => esc_html__('Background Color 2', 'fel'),
        'type' => Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .fel-ytLoader3 .dot:nth-child(2)' => 'background-color: {{VALUE}};',
        ],
        'condition' => [
          'setting_preloader' => 'style3'
        ],
      ]
    );

    $this->add_control(
      'style_preloader3_bgc3',
      [
        'label' => esc_html__('Background Color 3', 'fel'),
        'type' => Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .fel-ytLoader3 .dot:nth-child(3)' => 'background-color: {{VALUE}};',
        ],
        'condition' => [
          'setting_preloader' => 'style3'
        ],
      ]
    );

    $this->add_control(
      'style_preloader3_bgc4',
      [
        'label' => esc_html__('Background Color 4', 'fel'),
        'type' => Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .fel-ytLoader3 .dot:nth-child(4)' => 'background-color: {{VALUE}};',
        ],
        'condition' => [
          'setting_preloader' => 'style3'
        ],
      ]
    );

    $this->add_control(
      'style_preloader3_bgc5',
      [
        'label' => esc_html__('Background Color 5', 'fel'),
        'type' => Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .fel-ytLoader3 .dot:nth-child(5)' => 'background-color: {{VALUE}};',
        ],
        'condition' => [
          'setting_preloader' => 'style3'
        ],
      ]
    );
  }

  function ytLoader4()
  {
    $this->add_control(
      'style_preloader4_bgc1',
      [
        'label' => esc_html__('Background Color Circle', 'fel'),
        'type' => Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .fel-ytLoader4 .circle' => 'background-color: {{VALUE}};',
        ],
        'condition' => [
          'setting_preloader' => 'style4'
        ],
      ]
    );
    $this->add_control(
      'style_preloader4_bgc2',
      [
        'label' => esc_html__('Background Color Shadow', 'fel'),
        'type' => Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .fel-ytLoader4 .shadow' => 'background-color: {{VALUE}};',
        ],
        'condition' => [
          'setting_preloader' => 'style4'
        ],
      ]
    );
  }

  function ytLoader5()
  {
    $this->add_control(
      'style_preloader5_size',
      [
        'label' => esc_html__('Size Loader', 'fel'),
        'type' => Controls_Manager::SLIDER,
        'size_units' => ['px'],
        'range' => [
          'px' => [
            'min' => 0,
            'max' => 1000,
          ],
        ],
        'default' => [
          'size' => 15,
        ],
        'selectors' => [
          '{{WRAPPER}} .fel-ytLoader5' => 'height: {{SIZE}}{{UNIT}};',
        ],
        'condition' => [
          'setting_preloader' => 'style5'
        ],
      ]
    );

    $this->add_control(
      'style_preloader5_height',
      [
        'label' => esc_html__('Height content', 'fel'),
        'type' => Controls_Manager::SLIDER,
        'size_units' => ['px'],
        'range' => [
          'px' => [
            'min' => 0,
            'max' => 1000,
          ],
        ],
        'default' => [
          'size' => 15,
        ],
        'selectors' => [
          '{{WRAPPER}} .fel-ytLoader5:before, {{WRAPPER}} .fel-ytLoader5:after, ' => 'height: {{SIZE}}{{UNIT}};',
        ],
        'condition' => [
          'setting_preloader' => 'style5'
        ],
      ]
    );

    $this->add_control(
      'style_preloader5_bgc',
      [
        'label' => esc_html__('Background Color', 'fel'),
        'type' => Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .fel-ytLoader5:before' => 'background-image: linear-gradient(to right, transparent, {{VALUE}}, transparent);',
        ],
        'condition' => [
          'setting_preloader' => 'style5'
        ],
      ]
    );
  }

  function ytLoader6()
  {
    $this->add_control(
      'style_preloader6_bgc',
      [
        'label' => esc_html__('Background Color', 'fel'),
        'type' => Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .fel-ytLoader6 .box > div' => 'background: {{VALUE}};',
        ],
        'condition' => [
          'setting_preloader' => 'style6'
        ],
      ]
    );
  }

  function ytLoader7()
  {
    $this->add_control(
      'style_preloader7_size',
      [
        'label' => esc_html__('Size Loader', 'fel'),
        'type' => Controls_Manager::SLIDER,
        'size_units' => ['px'],
        'range' => [
          'px' => [
            'min' => 0,
            'max' => 1000,
          ],
        ],
        'default' => [
          'size' => 104,
        ],
        'selectors' => [
          '{{WRAPPER}} .fel-ytLoader7' => 'width: {{SIZE}}{{UNIT}};',
        ],
        'condition' => [
          'setting_preloader' => 'style7'
        ],
      ]
    );

    $this->add_control(
      'style_preloader7_size_blockw',
      [
        'label' => esc_html__('Size Block Width', 'fel'),
        'type' => Controls_Manager::SLIDER,
        'size_units' => ['px'],
        'range' => [
          'px' => [
            'min' => 0,
            'max' => 1000,
          ],
        ],
        'default' => [
          'size' => 24,
        ],
        'selectors' => [
          '{{WRAPPER}} .fel-ytLoader7 .loading-flag--flag' => 'width: {{SIZE}}{{UNIT}};',
        ],
        'condition' => [
          'setting_preloader' => 'style7'
        ],
      ]
    );

    $this->add_control(
      'style_preloader7_size_blockh',
      [
        'label' => esc_html__('Size Block Height', 'fel'),
        'type' => Controls_Manager::SLIDER,
        'size_units' => ['px'],
        'range' => [
          'px' => [
            'min' => 0,
            'max' => 1000,
          ],
        ],
        'default' => [
          'size' => 50,
        ],
        'selectors' => [
          '{{WRAPPER}} .fel-ytLoader7 .loading-flag--flag' => 'height: {{SIZE}}{{UNIT}};',
        ],
        'condition' => [
          'setting_preloader' => 'style7'
        ],
      ]
    );

    $this->add_control(
      'style_preloader7_size_itemw',
      [
        'label' => esc_html__('Size Line Width', 'fel'),
        'type' => Controls_Manager::SLIDER,
        'size_units' => ['px'],
        'range' => [
          'px' => [
            'min' => 0,
            'max' => 1000,
          ],
        ],
        'default' => [
          'size' => 3,
        ],
        'selectors' => [
          '{{WRAPPER}} .fel-ytLoader7 .loading-flag--flag .stripe' => 'width: {{SIZE}}{{UNIT}};',
        ],
        'condition' => [
          'setting_preloader' => 'style7'
        ],
      ]
    );

    $this->add_control(
      'style_preloader7_size_itemh',
      [
        'label' => esc_html__('Size Line Height', 'fel'),
        'type' => Controls_Manager::SLIDER,
        'size_units' => ['px'],
        'range' => [
          'px' => [
            'min' => 0,
            'max' => 1000,
          ],
        ],
        'default' => [
          'size' => 50,
        ],
        'selectors' => [
          '{{WRAPPER}} .fel-ytLoader7 .loading-flag--flag .stripe' => 'height: {{SIZE}}{{UNIT}};',
        ],
        'condition' => [
          'setting_preloader' => 'style7'
        ],
      ]
    );

    $this->add_control(
      'style_preloader7_bgc1',
      [
        'label' => esc_html__('Background Color 1', 'fel'),
        'type' => Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .fel-ytLoader7 .loading-flag--flag .stripe' => 'background: {{VALUE}};',
        ],
        'condition' => [
          'setting_preloader' => 'style7'
        ],
      ]
    );

    $this->add_control(
      'style_preloader7_bgc2',
      [
        'label' => esc_html__('Background Color 2', 'fel'),
        'type' => Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .fel-ytLoader7 .loading-flag--flag:first-child .stripe' => 'background: {{VALUE}};',
        ],
        'condition' => [
          'setting_preloader' => 'style7'
        ],
      ]
    );

    $this->add_control(
      'style_preloader7_bgc3',
      [
        'label' => esc_html__('Background Color 3', 'fel'),
        'type' => Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .fel-ytLoader7 .loading-flag--flag:nth-child(2) .stripe' => 'background: {{VALUE}};',
        ],
        'condition' => [
          'setting_preloader' => 'style7'
        ],
      ]
    );

    $this->add_control(
      'style_preloader7_bgc4',
      [
        'label' => esc_html__('Background Color 4', 'fel'),
        'type' => Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .fel-ytLoader7 .loading-flag--flag:nth-child(3) .stripe' => 'background: {{VALUE}};',
        ],
        'condition' => [
          'setting_preloader' => 'style7'
        ],
      ]
    );
  }

  function ytLoader8()
  {
    $this->add_control(
      'style_preloader8_size',
      [
        'label' => esc_html__('Size Loader', 'fel'),
        'type' => Controls_Manager::SLIDER,
        'size_units' => ['px'],
        'range' => [
          'px' => [
            'min' => 0,
            'max' => 1000,
          ],
        ],
        'default' => [
          'size' => 15,
        ],
        'selectors' => [
          '{{WRAPPER}} .fel-ytLoader8' => 'width: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}};',
        ],
        'condition' => [
          'setting_preloader' => 'style7'
        ],
      ]
    );

    $this->add_control(
      'style_preloader8_bgc1',
      [
        'label' => esc_html__('Background Color 1', 'fel'),
        'type' => Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .fel-ytLoader8' => 'background: {{VALUE}};',
        ],
        'condition' => [
          'setting_preloader' => 'style8'
        ],
      ]
    );

    $this->add_control(
      'style_preloader8_bgc2',
      [
        'label' => esc_html__('Background Color 2', 'fel'),
        'type' => Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .fel-ytLoader8::before' => 'background: {{VALUE}};',
        ],
        'condition' => [
          'setting_preloader' => 'style8'
        ],
      ]
    );

    $this->add_control(
      'style_preloader8_bgc3',
      [
        'label' => esc_html__('Background Color 3', 'fel'),
        'type' => Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .fel-ytLoader8::after' => 'background: {{VALUE}};',
        ],
        'condition' => [
          'setting_preloader' => 'style8'
        ],
      ]
    );
  }

  function ytLoader9()
  {
    $this->add_control(
      'style_preloader9_bgc1',
      [
        'label' => esc_html__('Color 1', 'fel'),
        'type' => Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .fel-ytLoader9 .blob-1' => 'background: {{VALUE}};',
        ],
        'condition' => [
          'setting_preloader' => 'style9'
        ],
      ]
    );

    $this->add_control(
      'style_preloader9_bgc2',
      [
        'label' => esc_html__('Color 2', 'fel'),
        'type' => Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .fel-ytLoader9 .blob-2' => 'background: {{VALUE}};',
        ],
        'condition' => [
          'setting_preloader' => 'style9'
        ],
      ]
    );
  }

  function ytLoader10()
  {
    $this->add_control(
      'style_preloader10_sizew',
      [
        'label' => esc_html__('Size Width', 'fel'),
        'type' => Controls_Manager::SLIDER,
        'size_units' => ['px'],
        'range' => [
          'px' => [
            'min' => 0,
            'max' => 1000,
          ],
        ],
        'default' => [
          'size' => 35,
        ],
        'selectors' => [
          '{{WRAPPER}} .fel-ytLoader10 .dash' => 'width: {{SIZE}}{{UNIT}};',
        ],
        'condition' => [
          'setting_preloader' => 'style10'
        ],
      ]
    );
    $this->add_control(
      'style_preloader10_sizeh',
      [
        'label' => esc_html__('Size Height', 'fel'),
        'type' => Controls_Manager::SLIDER,
        'size_units' => ['px'],
        'range' => [
          'px' => [
            'min' => 0,
            'max' => 1000,
          ],
        ],
        'default' => [
          'size' => 5,
        ],
        'selectors' => [
          '{{WRAPPER}} .fel-ytLoader10 .dash' => 'height: {{SIZE}}{{UNIT}};',
        ],
        'condition' => [
          'setting_preloader' => 'style10'
        ],
      ]
    );
    $this->add_control(
      'style_preloader10_sizebr',
      [
        'label' => esc_html__('Border radius', 'fel'),
        'type' => Controls_Manager::SLIDER,
        'size_units' => ['px'],
        'range' => [
          'px' => [
            'min' => 0,
            'max' => 1000,
          ],
        ],
        'default' => [
          'size' => 8,
        ],
        'selectors' => [
          '{{WRAPPER}} .fel-ytLoader10 .dash' => 'border-radius: {{SIZE}}{{UNIT}};',
        ],
        'condition' => [
          'setting_preloader' => 'style10'
        ],
      ]
    );
    $this->add_control(
      'style_preloader10_margin',
      [
        'label' => esc_html__('Margin', 'fel'),
        'type' => Controls_Manager::DIMENSIONS,
        'size_units' => ['px'],
        'selectors' => [
          '{{WRAPPER}} .fel-ytLoader10 .dash' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
        'condition' => [
          'setting_preloader' => 'style10'
        ],
      ]
    );
    $this->add_control(
      'style_preloader10_bgc',
      [
        'label' => esc_html__('Background Color', 'fel'),
        'type' => Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .fel-ytLoader10 .dash' => 'background: {{VALUE}};',
        ],
        'condition' => [
          'setting_preloader' => 'style10'
        ],
      ]
    );
    $this->add_group_control(
      \Elementor\Group_Control_Box_Shadow::get_type(),
      [
        'name' => 'style_preloader10_shadow',
        'label' => esc_html__('Box Shadow', 'fel'),
        'selector' => '{{WRAPPER}} .fel-ytLoader10 .dash',
        'condition' => [
          'setting_preloader' => 'style10'
        ],
      ]
    );
  }

  function ytLoader11()
  {
    $this->add_control(
      'style_preloader11_size',
      [
        'label' => esc_html__('Size Loader', 'fel'),
        'type' => Controls_Manager::SLIDER,
        'size_units' => ['px'],
        'range' => [
          'px' => [
            'min' => 0,
            'max' => 1000,
          ],
        ],
        'default' => [
          'size' => 20,
        ],
        'selectors' => [
          '{{WRAPPER}} .fel-ytLoader11 .item-1,{{WRAPPER}} .fel-ytLoader11 .item-2,{{WRAPPER}} .fel-ytLoader11 .item-3,{{WRAPPER}} .fel-ytLoader11 .item-4,{{WRAPPER}} .fel-ytLoader11 .item-5' => 'width: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}};',
        ],
        'condition' => [
          'setting_preloader' => 'style11'
        ],
      ]
    );
    $this->add_control(
      'style_preloader11_radius',
      [
        'label' => esc_html__('Size Loader', 'fel'),
        'type' => Controls_Manager::SLIDER,
        'size_units' => ['%'],
        'range' => [
          'px' => [
            'min' => 0,
            'max' => 100,
          ],
        ],
        'default' => [
          'size' => 50,
        ],
        'selectors' => [
          '{{WRAPPER}} .fel-ytLoader11 .item-1,{{WRAPPER}} .fel-ytLoader11 .item-2,{{WRAPPER}} .fel-ytLoader11 .item-3,{{WRAPPER}} .fel-ytLoader11 .item-4,{{WRAPPER}} .fel-ytLoader11 .item-5' => 'border-radius: {{SIZE}}{{UNIT}};',
          '{{WRAPPER}} .fel-ytLoader11 .item-1:before,{{WRAPPER}} .fel-ytLoader11 .item-2:before,{{WRAPPER}} .fel-ytLoader11 .item-3:before,{{WRAPPER}} .fel-ytLoader11 .item-4:before,{{WRAPPER}} .fel-ytLoader11 .item-5:before' => 'border-radius: {{SIZE}}{{UNIT}};',
        ],
        'condition' => [
          'setting_preloader' => 'style11'
        ],
      ]
    );
    $this->add_control(
      'style_preloader11_bgc1',
      [
        'label' => esc_html__('Background Color 1', 'fel'),
        'type' => Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .fel-ytLoader11 .item-1:before' => 'background: {{VALUE}};',
        ],
        'condition' => [
          'setting_preloader' => 'style11'
        ],
      ]
    );
    $this->add_control(
      'style_preloader11_bgc2',
      [
        'label' => esc_html__('Background Color 2', 'fel'),
        'type' => Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .fel-ytLoader11 .item-2:before' => 'background: {{VALUE}};',
        ],
        'condition' => [
          'setting_preloader' => 'style11'
        ],
      ]
    );
    $this->add_control(
      'style_preloader11_bgc3',
      [
        'label' => esc_html__('Background Color 3', 'fel'),
        'type' => Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .fel-ytLoader11 .item-3:before' => 'background: {{VALUE}};',
        ],
        'condition' => [
          'setting_preloader' => 'style11'
        ],
      ]
    );
    $this->add_control(
      'style_preloader11_bgc4',
      [
        'label' => esc_html__('Background Color 4', 'fel'),
        'type' => Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .fel-ytLoader11 .item-4:before' => 'background: {{VALUE}};',
        ],
        'condition' => [
          'setting_preloader' => 'style11'
        ],
      ]
    );
    $this->add_control(
      'style_preloader11_bgc5',
      [
        'label' => esc_html__('Background Color 5', 'fel'),
        'type' => Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .fel-ytLoader11 .item-5:before' => 'background: {{VALUE}};',
        ],
        'condition' => [
          'setting_preloader' => 'style11'
        ],
      ]
    );
  }

  function ytLoader12()
  {
    $this->add_control(
      'style_preloader12_size',
      [
        'label' => esc_html__('Size Loader', 'fel'),
        'type' => Controls_Manager::SLIDER,
        'size_units' => ['px'],
        'range' => [
          'px' => [
            'min' => 0,
            'max' => 1000,
          ],
        ],
        'default' => [
          'size' => 20,
        ],
        'selectors' => [
          '{{WRAPPER}} .fel-ytLoader12 ul li' => 'width: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}};',
        ],
        'condition' => [
          'setting_preloader' => 'style12'
        ],
      ]
    );
    $this->add_control(
      'style_preloader12_margin',
      [
        'label' => esc_html__('Margin', 'fel'),
        'type' => Controls_Manager::DIMENSIONS,
        'size_units' => ['px'],
        'selectors' => [
          '{{WRAPPER}} .fel-ytLoader12 ul li' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
        'condition' => [
          'setting_preloader' => 'style12'
        ],
      ]
    );
    $this->add_control(
      'style_preloader12_bgc1',
      [
        'label' => esc_html__('Background Color 1', 'fel'),
        'type' => Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .fel-ytLoader12 ul li:nth-child(1)' => 'background: {{VALUE}};',
        ],
        'condition' => [
          'setting_preloader' => 'style12'
        ],
      ]
    );
    $this->add_control(
      'style_preloader12_bgc2',
      [
        'label' => esc_html__('Background Color 2', 'fel'),
        'type' => Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .fel-ytLoader12 ul li:nth-child(2)' => 'background: {{VALUE}};',
        ],
        'condition' => [
          'setting_preloader' => 'style12'
        ],
      ]
    );
    $this->add_control(
      'style_preloader12_bgc3',
      [
        'label' => esc_html__('Background Color 3', 'fel'),
        'type' => Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .fel-ytLoader12 ul li:nth-child(3)' => 'background: {{VALUE}};',
        ],
        'condition' => [
          'setting_preloader' => 'style12'
        ],
      ]
    );
    $this->add_control(
      'style_preloader12_bgc4',
      [
        'label' => esc_html__('Background Color 4', 'fel'),
        'type' => Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .fel-ytLoader12 ul li:nth-child(4)' => 'background: {{VALUE}};',
        ],
        'condition' => [
          'setting_preloader' => 'style12'
        ],
      ]
    );
    $this->add_control(
      'style_preloader12_bgc5',
      [
        'label' => esc_html__('Background Color 5', 'fel'),
        'type' => Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .fel-ytLoader12 ul li:nth-child(5)' => 'background: {{VALUE}};',
        ],
        'condition' => [
          'setting_preloader' => 'style12'
        ],
      ]
    );
  }

  function ytLoader13()
  {
    $this->add_control(
      'style_preloader13_size',
      [
        'label' => esc_html__('Size Loader', 'fel'),
        'type' => Controls_Manager::SLIDER,
        'size_units' => ['px'],
        'range' => [
          'px' => [
            'min' => 0,
            'max' => 1000,
          ],
        ],
        'default' => [
          'size' => 13,
        ],
        'selectors' => [
          '{{WRAPPER}} .fel-ytLoader13' => 'width: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}};',
        ],
        'condition' => [
          'setting_preloader' => 'style13'
        ],
      ]
    );
    $this->add_control(
      'style_preloader13_grid',
      [
        'label' => esc_html__('Size Loader', 'fel'),
        'type' => Controls_Manager::SLIDER,
        'size_units' => ['px'],
        'range' => [
          'px' => [
            'min' => 0,
            'max' => 100,
          ],
        ],
        'default' => [
          'size' => 2,
        ],
        'selectors' => [
          '{{WRAPPER}} .fel-ytLoader13' => 'grid-gap: {{SIZE}}{{UNIT}};',
        ],
        'condition' => [
          'setting_preloader' => 'style13'
        ],
      ]
    );
    $this->add_control(
      'style_preloader13_bgc',
      [
        'label' => esc_html__('Background Color', 'fel'),
        'type' => Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .fel-ytLoader13 > div' => 'background: {{VALUE}};',
        ],
        'condition' => [
          'setting_preloader' => 'style13'
        ],
      ]
    );
  }

  function ytLoader14()
  {
    $this->add_control(
      'style_preloader14_size',
      [
        'label' => esc_html__('Size Loader', 'fel'),
        'type' => Controls_Manager::SLIDER,
        'size_units' => ['px'],
        'range' => [
          'px' => [
            'min' => 0,
            'max' => 1000,
          ],
        ],
        'default' => [
          'size' => 50,
        ],
        'selectors' => [
          '{{WRAPPER}} .fel-ytLoader14' => 'width: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}};',
        ],
        'condition' => [
          'setting_preloader' => 'style14'
        ],
      ]
    );
    $this->add_control(
      'style_preloader14_item',
      [
        'label' => esc_html__('Size Item', 'fel'),
        'type' => Controls_Manager::SLIDER,
        'size_units' => ['px'],
        'range' => [
          'px' => [
            'min' => 0,
            'max' => 1000,
          ],
        ],
        'default' => [
          'size' => 25,
        ],
        'selectors' => [
          '{{WRAPPER}} .fel-ytLoader14 .item' => 'width: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}};',
        ],
        'condition' => [
          'setting_preloader' => 'style14'
        ],
      ]
    );
    $this->add_control(
      'style_preloader14_bgc1',
      [
        'label' => esc_html__('Background Color 1', 'fel'),
        'type' => Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .fel-ytLoader14 .item-1' => 'background: {{VALUE}};',
        ],
        'condition' => [
          'setting_preloader' => 'style14'
        ],
      ]
    );
    $this->add_control(
      'style_preloader14_bgc2',
      [
        'label' => esc_html__('Background Color 2', 'fel'),
        'type' => Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .fel-ytLoader14 .item-2' => 'background: {{VALUE}};',
        ],
        'condition' => [
          'setting_preloader' => 'style14'
        ],
      ]
    );
    $this->add_control(
      'style_preloader14_bgc3',
      [
        'label' => esc_html__('Background Color 3', 'fel'),
        'type' => Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .fel-ytLoader14 .item-3' => 'background: {{VALUE}};',
        ],
        'condition' => [
          'setting_preloader' => 'style14'
        ],
      ]
    );
    $this->add_control(
      'style_preloader14_bgc4',
      [
        'label' => esc_html__('Background Color 4', 'fel'),
        'type' => Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .fel-ytLoader14 .item-4' => 'background: {{VALUE}};',
        ],
        'condition' => [
          'setting_preloader' => 'style14'
        ],
      ]
    );
  }

  function ytLoader15()
  {
    $this->add_control(
      'style_preloader15_size',
      [
        'label' => esc_html__('Size Loader', 'fel'),
        'type' => Controls_Manager::SLIDER,
        'size_units' => ['px'],
        'range' => [
          'px' => [
            'min' => 0,
            'max' => 1000,
          ],
        ],
        'default' => [
          'size' => 70,
        ],
        'selectors' => [
          '{{WRAPPER}} .fel-ytLoader16' => 'width: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}};',
        ],
        'condition' => [
          'setting_preloader' => 'style15'
        ],
      ]
    );
    $this->add_control(
      'style_preloader15_item',
      [
        'label' => esc_html__('Size Loader', 'fel'),
        'type' => Controls_Manager::SLIDER,
        'size_units' => ['px'],
        'range' => [
          'px' => [
            'min' => 0,
            'max' => 1000,
          ],
        ],
        'default' => [
          'size' => 50,
        ],
        'selectors' => [
          '{{WRAPPER}} .fel-ytLoader16 #box' => 'width: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}};',
        ],
        'condition' => [
          'setting_preloader' => 'style15'
        ],
      ]
    );
    $this->add_control(
      'style_preloader15_bgc',
      [
        'label' => esc_html__('Background Color', 'fel'),
        'type' => Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .fel-ytLoader16 #box' => 'background: {{VALUE}};',
        ],
        'condition' => [
          'setting_preloader' => 'style15'
        ],
      ]
    );
    $this->add_control(
      'style_preloader15_bgcsha',
      [
        'label' => esc_html__('Background Color Shadow', 'fel'),
        'type' => Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .fel-ytLoader16 #shadow' => 'background: {{VALUE}};',
        ],
        'condition' => [
          'setting_preloader' => 'style15'
        ],
      ]
    );
  }

  function ytSetting()
  {
    $this->start_controls_section(
      'section_settings',
      [
        'label' => esc_html__('General', 'fel'),
        'tab' => Controls_Manager::TAB_SETTINGS,
      ]
    );

    $this->add_control(
      'per_line',
      [
        'label' => esc_html__('Columns', 'fel'),
        'type' => Controls_Manager::SELECT,
        'default' => '3',
        'tablet_default' => '2',
        'mobile_default' => '1',
        'options' => [
          '1' => '1',
          '2' => '2',
          '3' => '3',
          '4' => '4',
          '5' => '5',
          '6' => '6',
        ],
        'frontend_available' => true,
      ]
    );

    $this->add_control(
      'layout_video',
      [
        'type' => Controls_Manager::SELECT,
        'label' => esc_html__('Choose a layout Videos', 'fel'),
        'options' => array(
          'videoinline' => esc_html__('Video Inline', 'fel'),
          'newtab' => esc_html__('Open New Tab', 'fel'),
          'popup' => esc_html__('Video Popup', 'fel'),
        ),
        'default' => 'videoinline',
      ]
    );

    $this->add_control(
      'layout_grid',
      [
        'type' => Controls_Manager::SELECT,
        'label' => esc_html__('Choose a YouTube Grid', 'fel'),
        'options' => array(
          'mansory' => esc_html__('Grid Mansory', 'fel'),
          'slider1' => esc_html__('Grid Slider 1 row', 'fel'),
          'slider2' => esc_html__('Grid Slider 2 rows', 'fel'),
          'tab' => esc_html__('Grid tab', 'fel'),
        ),
        'default' => 'mansory',
      ]
    );

    $this->add_control(
      'layout_videos',
      [
        'label' => esc_html__('Get number videos', 'fel'),
        'type' => Controls_Manager::SLIDER,
        'range' => [
          'px' => [
            'min' => 10,
            'max' => 100,
          ],
        ],
        'default' => [
          'size' => 10,
        ],
      ]
    );

    $this->add_control(
      'setting_layout_videos',
      [
        'label' => esc_attr__('Layout slider', 'fel'),
        'type' => Controls_Manager::HEADING,
        'condition' => [
          'layout_grid' => ['slider1', 'slider2', 'tab']
        ],
      ]
    );

    $this->add_control(
      'layout_videos_nav',
      [
        'label' => esc_html__('Show Nav?', 'fel'),
        'type' => Controls_Manager::SWITCHER,
        'label_on' => esc_html__('Yes', 'fel'),
        'label_off' => esc_html__('No', 'fel'),
        'return_value' => 'yes',
        'default' => 'no',
        'condition' => [
          'layout_grid' => ['slider1', 'slider2', 'tab']
        ],
      ]
    );

    $this->add_control(
      'layout_videos_dots',
      [
        'label' => esc_html__('Show Dots?', 'fel'),
        'type' => Controls_Manager::SWITCHER,
        'label_on' => esc_html__('Yes', 'fel'),
        'label_off' => esc_html__('No', 'fel'),
        'return_value' => 'yes',
        'default' => 'no',
        'condition' => [
          'layout_grid' => ['slider1', 'slider2', 'tab']
        ],
      ]
    );

    $this->add_control(
      'layout_videos_distant',
      [
        'label' => esc_html__('Distant item video', 'fel'),
        'type' => Controls_Manager::SLIDER,
        'range' => [
          'px' => [
            'min' => 0,
            'max' => 100,
          ],
        ],
        'default' => [
          'size' => 10,
        ],
        'condition' => [
          'layout_grid' => ['slider1', 'slider2', 'tab']
        ],
      ]
    );

    $this->add_control(
      'setting_layout_videos_nav',
      [
        'label' => esc_attr__('Setting nav', 'fel'),
        'type' => Controls_Manager::HEADING,
        'condition' => [
          'layout_grid' => ['slider1', 'slider2', 'tab'],
          'layout_videos_nav' => ['yes']
        ],
      ]
    );

    $this->add_control('icon_prev',
      [
        'label' => esc_html__('Icon Prev', 'fel'),
        'type' => Controls_Manager::ICON,
        'default' => 'fa fa-chevron-left',
        'condition' => [
          'layout_grid' => ['slider1', 'slider2', 'tab'],
          'layout_videos_nav' => ['yes']
        ],
      ]
    );

    $this->add_control('icon_prev_color',
      [
        'label' => esc_html__('Color Icon Prev', 'fel'),
        'type' => Controls_Manager::COLOR,
        'default' => '#000',
        'selectors' => [
          '{{WRAPPER}} .owl-carousel.fel-ytWrap__content .owl-nav .owl-prev i' => 'color: {{VALUE}};',
          '{{WRAPPER}} .fel-ytWrap__content.fel-ytWrap__tabContent .owl-carousel .owl-nav .owl-prev i' => 'color: {{VALUE}};',
        ],
        'condition' => [
          'layout_grid' => ['slider1', 'slider2', 'tab'],
          'layout_videos_nav' => ['yes']
        ],
      ]
    );

    $this->add_control('icon_prev_color_hover',
      [
        'label' => esc_html__('Color Icon Prev Hover', 'fel'),
        'type' => Controls_Manager::COLOR,
        'default' => '#000',
        'selectors' => [
          '{{WRAPPER}} .owl-carousel.fel-ytWrap__content .owl-nav .owl-prev:hover i' => 'color: {{VALUE}};',
          '{{WRAPPER}} .fel-ytWrap__content.fel-ytWrap__tabContent .owl-carousel .owl-nav .owl-prev:hover i' => 'color: {{VALUE}};',
        ],
        'condition' => [
          'layout_grid' => ['slider1', 'slider2', 'tab'],
          'layout_videos_nav' => ['yes']
        ],
      ]
    );

    $this->add_control('icon_next',
      [
        'label' => esc_html__('Icon Next', 'fel'),
        'type' => Controls_Manager::ICON,
        'default' => 'fa fa-chevron-right',
        'condition' => [
          'layout_grid' => ['slider1', 'slider2', 'tab'],
          'layout_videos_nav' => ['yes']
        ],
      ]
    );

    $this->add_control('icon_next_color',
      [
        'label' => esc_html__('Color Icon Next', 'fel'),
        'type' => Controls_Manager::COLOR,
        'default' => '#000',
        'selectors' => [
          '{{WRAPPER}} .owl-carousel.fel-ytWrap__content .owl-nav .owl-next i' => 'color: {{VALUE}};',
          '{{WRAPPER}} .fel-ytWrap__content.fel-ytWrap__tabContent .owl-carousel .owl-nav .owl-next i' => 'color: {{VALUE}};',
        ],
        'condition' => [
          'layout_grid' => ['slider1', 'slider2', 'tab'],
          'layout_videos_nav' => ['yes']
        ],
      ]
    );

    $this->add_control('icon_next_color_hover',
      [
        'label' => esc_html__('Color Icon Hover', 'fel'),
        'type' => Controls_Manager::COLOR,
        'default' => '#fff000',
        'selectors' => [
          '{{WRAPPER}} .owl-carousel.fel-ytWrap__content .owl-nav .owl-next:hover i' => 'color: {{VALUE}};',
          '{{WRAPPER}} .owl-carousel.fel-ytWrap__content .owl-nav .owl-prev:hover i' => 'color: {{VALUE}};',
          '{{WRAPPER}} .fel-ytWrap__content.fel-ytWrap__tabContent .owl-carousel .owl-nav .owl-prev:hover i' => 'color: {{VALUE}};',
          '{{WRAPPER}} .fel-ytWrap__content.fel-ytWrap__tabContent .owl-carousel .owl-nav .owl-next:hover i' => 'color: {{VALUE}};',
        ],
        'condition' => [
          'layout_grid' => ['slider1', 'slider2', 'tab'],
          'layout_videos_nav' => ['yes']
        ],
      ]
    );

    $this->add_control(
      'nav_position',
      [
        'type' => Controls_Manager::SELECT,
        'label' => esc_html__('Nav position', 'fel'),
        'options' => array(
          'space_out' => esc_html__('Space between center', 'fel'),
          'left_top' => esc_html__('Left top', 'fel'),
          'left_center' => esc_html__('Left center', 'fel'),
          'left_bottom' => esc_html__('Left bottom', 'fel'),
          'right_top' => esc_html__('Right top', 'fel'),
          'right_center' => esc_html__('Right center', 'fel'),
          'right_bottom' => esc_html__('Right bottom', 'fel'),
          'top_center' => esc_html__('Top center', 'fel'),
          'bottom_center' => esc_html__('Bottom center', 'fel'),
        ),
        'default' => 'space_out',
        'condition' => [
          'layout_grid' => ['slider1', 'slider2', 'tab'],
          'layout_videos_nav' => ['yes']
        ],
      ]
    );

    $this->add_responsive_control(
      'size_icon',
      [
        'label' => esc_html__('Size icon', 'fel'),
        'type' => Controls_Manager::SLIDER,
        'default' => [
          'size' => 13,
        ],
        'range' => [
          'px' => [
            'min' => 1,
            'max' => 100,
          ],
        ],
        'selectors' => [
          '{{WRAPPER}} .owl-carousel.fel-ytWrap__content .owl-nav i' => 'font-size: {{SIZE}}{{UNIT}};',
          '{{WRAPPER}} .fel-ytWrap__content.fel-ytWrap__tabContent .owl-nav i' => 'font-size: {{SIZE}}{{UNIT}};',
        ],
        'condition' => [
          'layout_grid' => ['slider1', 'slider2', 'tab'],
          'layout_videos_nav' => ['yes']
        ],
      ]
    );

    $this->add_responsive_control(
      'nav_position_out',
      [
        'label' => esc_html__('Position nav', 'fel'),
        'type' => Controls_Manager::SLIDER,
        'default' => [
          'size' => -30,
        ],
        'range' => [
          'px' => [
            'min' => -100,
            'max' => 100,
          ],
        ],
        'selectors' => [
          '{{WRAPPER}} .owl-carousel.fel-ytWrap__content.space_out .owl-nav .owl-prev' => 'left: {{SIZE}}{{UNIT}};',
          '{{WRAPPER}} .owl-carousel.fel-ytWrap__content.space_out .owl-nav .owl-next' => 'right: {{SIZE}}{{UNIT}};',
          '{{WRAPPER}} .fel-ytWrap__content.fel-ytWrap__tabContent.space_out .owl-nav .owl-prev' => 'left: {{SIZE}}{{UNIT}};',
          '{{WRAPPER}} .fel-ytWrap__content.fel-ytWrap__tabContent.space_out .owl-nav .owl-next' => 'right: {{SIZE}}{{UNIT}};',
        ],
        'condition' => [
          'layout_grid' => ['slider1', 'slider2', 'tab'],
          'layout_videos_nav' => ['yes'],
          'nav_position' => ['space_out']
        ],
      ]
    );

    $this->add_responsive_control(
      'nav_position_topcenter1',
      [
        'label' => esc_html__('Top position', 'fel'),
        'type' => Controls_Manager::SLIDER,
        'default' => [
          'size' => -30,
        ],
        'range' => [
          'px' => [
            'min' => -100,
            'max' => 100,
          ],
        ],
        'selectors' => [
          '{{WRAPPER}} .owl-carousel.fel-ytWrap__content .owl-nav' => 'top: {{SIZE}}{{UNIT}};',
          '{{WRAPPER}} .fel-ytWrap__content.fel-ytWrap__tabContent .owl-nav' => 'top: {{SIZE}}{{UNIT}};',
        ],
        'condition' => [
          'layout_grid' => ['slider1', 'slider2', 'tab'],
          'layout_videos_nav' => ['yes'],
          'nav_position' => ['top_center']
        ],
      ]
    );

    $this->add_responsive_control(
      'nav_position_bottomcenter1',
      [
        'label' => esc_html__('Top position', 'fel'),
        'type' => Controls_Manager::SLIDER,
        'default' => [
          'size' => -30,
        ],
        'range' => [
          'px' => [
            'min' => -100,
            'max' => 100,
          ],
        ],
        'selectors' => [
          '{{WRAPPER}} .owl-carousel.fel-ytWrap__content.bottom_center .owl-prev' => 'margin-bottom: {{SIZE}}{{UNIT}};',
          '{{WRAPPER}} .owl-carousel.fel-ytWrap__content.bottom_center .owl-next' => 'margin-bottom: {{SIZE}}{{UNIT}};',
          '{{WRAPPER}} .fel-ytWrap__content.fel-ytWrap__tabContent.bottom_center .owl-nav .owl-prev' => 'margin-bottom: {{SIZE}}{{UNIT}};',
          '{{WRAPPER}} .fel-ytWrap__content.fel-ytWrap__tabContent.bottom_center .owl-nav .owl-next' => 'margin-bottom: {{SIZE}}{{UNIT}};',
        ],
        'condition' => [
          'layout_grid' => ['slider1', 'slider2', 'tab'],
          'layout_videos_nav' => ['yes'],
          'nav_position' => ['bottom_center']
        ],
      ]
    );

    $this->add_responsive_control(
      'nav_position_topleft1',
      [
        'label' => esc_html__('Top position', 'fel'),
        'type' => Controls_Manager::SLIDER,
        'default' => [
          'size' => -30,
        ],
        'range' => [
          'px' => [
            'min' => -100,
            'max' => 100,
          ],
        ],
        'selectors' => [
          '{{WRAPPER}} .owl-carousel.fel-ytWrap__content.left_top .owl-nav' => 'top: {{SIZE}}{{UNIT}};',
          '{{WRAPPER}} .fel-ytWrap__content.fel-ytWrap__tabContent.left_top .owl-nav' => 'top: {{SIZE}}{{UNIT}};',
        ],
        'condition' => [
          'layout_grid' => ['slider1', 'slider2', 'tab'],
          'layout_videos_nav' => ['yes'],
          'nav_position' => ['left_top']
        ],
      ]
    );

    $this->add_responsive_control(
      'nav_position_leftcenter1',
      [
        'label' => esc_html__('Top position', 'fel'),
        'type' => Controls_Manager::SLIDER,
        'default' => [
          'size' => -30,
        ],
        'range' => [
          'px' => [
            'min' => -100,
            'max' => 100,
          ],
        ],
        'selectors' => [
          '{{WRAPPER}} .owl-carousel.fel-ytWrap__content.left_center .owl-prev' => 'margin-top: {{SIZE}}{{UNIT}};',
          '{{WRAPPER}} .owl-carousel.fel-ytWrap__content.left_center .owl-next' => 'margin-top: {{SIZE}}{{UNIT}};',
          '{{WRAPPER}} .fel-ytWrap__content.fel-ytWrap__tabContent.left_center .owl-nav .owl-prev' => 'margin-top: {{SIZE}}{{UNIT}};',
          '{{WRAPPER}} .fel-ytWrap__content.fel-ytWrap__tabContent.left_center .owl-nav .owl-next' => 'margin-top: {{SIZE}}{{UNIT}};',
        ],
        'condition' => [
          'layout_grid' => ['slider1', 'slider2', 'tab'],
          'layout_videos_nav' => ['yes'],
          'nav_position' => ['left_center']
        ],
      ]
    );

    $this->add_responsive_control(
      'nav_position_leftbottom1',
      [
        'label' => esc_html__('Top position', 'fel'),
        'type' => Controls_Manager::SLIDER,
        'default' => [
          'size' => -30,
        ],
        'range' => [
          'px' => [
            'min' => -100,
            'max' => 100,
          ],
        ],
        'selectors' => [
          '{{WRAPPER}} .owl-carousel.fel-ytWrap__content.left_bottom .owl-nav' => 'margin-bottom: {{SIZE}}{{UNIT}};',
          '{{WRAPPER}} .fel-ytWrap__content.fel-ytWrap__tabContent.left_bottom .owl-nav' => 'bottom: {{SIZE}}{{UNIT}};',
        ],
        'condition' => [
          'layout_grid' => ['slider1', 'slider2', 'tab'],
          'layout_videos_nav' => ['yes'],
          'nav_position' => ['left_bottom']
        ],
      ]
    );

    $this->add_responsive_control(
      'nav_position_topright1',
      [
        'label' => esc_html__('Top position', 'fel'),
        'type' => Controls_Manager::SLIDER,
        'default' => [
          'size' => -30,
        ],
        'range' => [
          'px' => [
            'min' => -100,
            'max' => 100,
          ],
        ],
        'selectors' => [
          '{{WRAPPER}} .owl-carousel.fel-ytWrap__content.right_top .owl-nav' => 'margin-top: {{SIZE}}{{UNIT}};',
          '{{WRAPPER}} .fel-ytWrap__content.fel-ytWrap__tabContent.right_top .owl-nav' => 'top: {{SIZE}}{{UNIT}};',
        ],
        'condition' => [
          'layout_grid' => ['slider1', 'slider2', 'tab'],
          'layout_videos_nav' => ['yes'],
          'nav_position' => ['right_top']
        ],
      ]
    );

    $this->add_responsive_control(
      'nav_position_rightcenter1',
      [
        'label' => esc_html__('Top position', 'fel'),
        'type' => Controls_Manager::SLIDER,
        'default' => [
          'size' => -30,
        ],
        'range' => [
          'px' => [
            'min' => -100,
            'max' => 100,
          ],
        ],
        'selectors' => [
          '{{WRAPPER}} .owl-carousel.fel-ytWrap__content.right_center .owl-prev' => 'margin-top: {{SIZE}}{{UNIT}};',
          '{{WRAPPER}} .owl-carousel.fel-ytWrap__content.right_center .owl-next' => 'margin-top: {{SIZE}}{{UNIT}};',
          '{{WRAPPER}} .fel-ytWrap__content.fel-ytWrap__tabContent.right_center .owl-nav .owl-prev' => 'margin-top: {{SIZE}}{{UNIT}};',
          '{{WRAPPER}} .fel-ytWrap__content.fel-ytWrap__tabContent.right_center .owl-nav .owl-next' => 'margin-top: {{SIZE}}{{UNIT}};',
        ],
        'condition' => [
          'layout_grid' => ['slider1', 'slider2', 'tab'],
          'layout_videos_nav' => ['yes'],
          'nav_position' => ['right_center']
        ],
      ]
    );

    $this->add_responsive_control(
      'nav_position_rightbottom1',
      [
        'label' => esc_html__('Top position', 'fel'),
        'type' => Controls_Manager::SLIDER,
        'default' => [
          'size' => -30,
        ],
        'range' => [
          'px' => [
            'min' => -100,
            'max' => 100,
          ],
        ],
        'selectors' => [
          '{{WRAPPER}} .owl-carousel.fel-ytWrap__content.right_bottom .owl-nav' => 'bottom: {{SIZE}}{{UNIT}};',
          '{{WRAPPER}} .fel-ytWrap__content.fel-ytWrap__tabContent.right_bottom .owl-nav' => 'bottom: {{SIZE}}{{UNIT}};',
        ],
        'condition' => [
          'layout_grid' => ['slider1', 'slider2', 'tab'],
          'layout_videos_nav' => ['yes'],
          'nav_position' => ['right_bottom']
        ],
      ]
    );

    $this->add_responsive_control(
      'nav_position_dis2button',
      [
        'label' => esc_html__('Distant two button', 'fel'),
        'type' => Controls_Manager::SLIDER,
        'default' => [
          'size' => 0,
        ],
        'range' => [
          'px' => [
            'min' => -100,
            'max' => 100,
          ],
        ],
        'selectors' => [
          '{{WRAPPER}} .owl-carousel.fel-ytWrap__content .owl-nav .owl-prev' => 'margin-left: {{SIZE}}{{UNIT}};',
          '{{WRAPPER}} .owl-carousel.fel-ytWrap__content .owl-nav .owl-next' => 'margin-right: {{SIZE}}{{UNIT}};',
          '{{WRAPPER}} .fel-ytWrap__content.fel-ytWrap__tabContent .owl-nav .owl-prev' => 'margin-left: {{SIZE}}{{UNIT}};',
          '{{WRAPPER}} .fel-ytWrap__content.fel-ytWrap__tabContent .owl-nav .owl-next' => 'margin-right: {{SIZE}}{{UNIT}};',
        ],
        'condition' => [
          'layout_grid' => ['slider1', 'slider2', 'tab'],
          'layout_videos_nav' => ['yes'],
        ],
      ]
    );

    $this->add_responsive_control(
      'size_icon_width',
      [
        'label' => esc_html__('Width icon', 'fel'),
        'type' => Controls_Manager::SLIDER,
        'default' => [
          'size' => 13,
        ],
        'range' => [
          'px' => [
            'min' => 1,
            'max' => 100,
          ],
        ],
        'selectors' => [
          '{{WRAPPER}} .owl-carousel.fel-ytWrap__content .owl-nav .owl-prev' => 'width: {{SIZE}}{{UNIT}};',
          '{{WRAPPER}} .owl-carousel.fel-ytWrap__content .owl-nav .owl-next' => 'width: {{SIZE}}{{UNIT}};',
          '{{WRAPPER}} .fel-ytWrap__content.fel-ytWrap__tabContent .owl-nav .owl-prev' => 'width: {{SIZE}}{{UNIT}};',
          '{{WRAPPER}} .fel-ytWrap__content.fel-ytWrap__tabContent .owl-nav .owl-next' => 'width: {{SIZE}}{{UNIT}};',
        ],
        'condition' => [
          'layout_grid' => ['slider1', 'slider2', 'tab'],
          'layout_videos_nav' => ['yes']
        ],
      ]
    );

    $this->add_responsive_control(
      'size_icon_height',
      [
        'label' => esc_html__('Height icon', 'fel'),
        'type' => Controls_Manager::SLIDER,
        'default' => [
          'size' => 13,
        ],
        'range' => [
          'px' => [
            'min' => 1,
            'max' => 100,
          ],
        ],
        'selectors' => [
          '{{WRAPPER}} .owl-carousel.fel-ytWrap__content .owl-nav .owl-prev' => 'height: {{SIZE}}{{UNIT}};',
          '{{WRAPPER}} .owl-carousel.fel-ytWrap__content .owl-nav .owl-next' => 'height: {{SIZE}}{{UNIT}};',
          '{{WRAPPER}} .fel-ytWrap__content.fel-ytWrap__tabContent .owl-nav .owl-prev' => 'height: {{SIZE}}{{UNIT}};',
          '{{WRAPPER}} .fel-ytWrap__content.fel-ytWrap__tabContent .owl-nav .owl-next' => 'height: {{SIZE}}{{UNIT}};',
        ],
        'condition' => [
          'layout_grid' => ['slider1', 'slider2', 'tab'],
          'layout_videos_nav' => ['yes']
        ],
      ]
    );

    $this->add_responsive_control(
      'nav_radius',
      [
        'label' => esc_html__('Nav radius', 'fel'),
        'type' => Controls_Manager::DIMENSIONS,
        'default' => [
          'top' => '3',
          'right' => '3',
          'bottom' => '3',
          'left' => '3',
        ],
        'range' => [
          'px' => [
            'min' => 0,
            'max' => 1000,
          ],
        ],
        'selectors' => [
          '{{WRAPPER}}  .owl-carousel.fel-ytWrap__content .owl-nav .owl-prev' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
          '{{WRAPPER}}  .owl-carousel.fel-ytWrap__content .owl-nav .owl-next' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
          '{{WRAPPER}}  .fel-ytWrap__content.fel-ytWrap__tabContent .owl-nav .owl-prev' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
          '{{WRAPPER}}  .fel-ytWrap__content.fel-ytWrap__tabContent .owl-nav .owl-next' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
        'condition' => [
          'layout_grid' => ['slider1', 'slider2', 'tab'],
          'layout_videos_nav' => ['yes']
        ],
      ]
    );

    $this->add_control(
      'style_size_icon_border_color',
      [
        'label' => esc_attr__('Border icon', 'fel'),
        'type' => Controls_Manager::HEADING,
        'condition' => [
          'layout_grid' => ['slider1', 'slider2', 'tab'],
          'layout_videos_nav' => ['yes']
        ],
      ]
    );

    $this->add_group_control(
      Group_Control_Border::get_type(),
      [
        'name' => 'size_icon_border_color',
        'label' => esc_attr__('Border icon color', 'fel'),
        'types' => ['classic', 'gradient'],
        'selector' =>
          '{{WRAPPER}} .fel-ytWrap__content.fel-ytWrap__tabContent .owl-carousel .owl-nav .owl-next,
          {{WRAPPER}}  .fel-ytWrap__content.fel-ytWrap__tabContent .owl-carousel .owl-nav .owl-prev,
          {{WRAPPER}}  .owl-carousel.fel-ytWrap__content .owl-nav .owl-prev,
          {{WRAPPER}}  .owl-carousel.fel-ytWrap__content .owl-nav .owl-next',
        'condition' => [
          'layout_grid' => ['slider1', 'slider2', 'tab'],
          'layout_videos_nav' => ['yes']
        ],
      ]
    );

    $this->add_control(
      'style_size_icon_border_color_hover',
      [
        'label' => esc_attr__('Border icon color hover', 'fel'),
        'type' => Controls_Manager::HEADING,
        'condition' => [
          'layout_grid' => ['slider1', 'slider2', 'tab'],
          'layout_videos_nav' => ['yes']
        ],
      ]
    );

    $this->add_group_control(
      Group_Control_Border::get_type(),
      [
        'name' => 'size_icon_border_color_hover',
        'label' => esc_attr__('Border icon color', 'fel'),
        'types' => ['classic', 'gradient'],
        'selector' =>
          '{{WRAPPER}} .fel-ytWrap__content.fel-ytWrap__tabContent .owl-carousel .owl-nav .owl-next:hover,
          {{WRAPPER}}  .fel-ytWrap__content.fel-ytWrap__tabContent .owl-carousel .owl-nav .owl-prev:hover,
          {{WRAPPER}}  .owl-carousel.fel-ytWrap__content .owl-nav .owl-prev:hover,
          {{WRAPPER}}  .owl-carousel.fel-ytWrap__content .owl-nav .owl-next:hover',
        'condition' => [
          'layout_grid' => ['slider1', 'slider2', 'tab'],
          'layout_videos_nav' => ['yes']
        ],
      ]
    );

    $this->add_control(
      'style_size_icon_bg_color',
      [
        'label' => esc_attr__('Background', 'fel'),
        'type' => Controls_Manager::HEADING,
        'condition' => [
          'layout_grid' => ['slider1', 'slider2', 'tab'],
          'layout_videos_nav' => ['yes']
        ],
      ]
    );

    $this->add_control(
      'size_icon_bg_color',
      [
        'label' => esc_attr__('Background icon color', 'fel'),
        'type' => Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .owl-carousel.fel-ytWrap__content .owl-nav .owl-prev' => 'background-color: {{VALUE}};',
          '{{WRAPPER}} .owl-carousel.fel-ytWrap__content .owl-nav .owl-next' => 'background-color: {{VALUE}};',
          '{{WRAPPER}} .fel-ytWrap__content.fel-ytWrap__tabContent .owl-nav .owl-prev' => 'background-color: {{VALUE}};',
          '{{WRAPPER}} .fel-ytWrap__content.fel-ytWrap__tabContent .owl-nav .owl-next' => 'background-color: {{VALUE}};',
        ],
        'condition' => [
          'layout_grid' => ['slider1', 'slider2', 'tab'],
          'layout_videos_nav' => ['yes']
        ],
      ]
    );

    $this->add_control(
      'size_icon_bg_color_hover',
      [
        'label' => esc_attr__('Background icon color hover', 'fel'),
        'type' => Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .owl-carousel.fel-ytWrap__content .owl-nav .owl-prev:hover' => 'background-color: {{VALUE}};',
          '{{WRAPPER}} .owl-carousel.fel-ytWrap__content .owl-nav .owl-next:hover' => 'background-color: {{VALUE}};',
          '{{WRAPPER}} .fel-ytWrap__content.fel-ytWrap__tabContent .owl-nav .owl-prev:hover' => 'background-color: {{VALUE}};',
          '{{WRAPPER}} .fel-ytWrap__content.fel-ytWrap__tabContent .owl-nav .owl-next:hover' => 'background-color: {{VALUE}};',
        ],
        'condition' => [
          'layout_grid' => ['slider1', 'slider2', 'tab'],
          'layout_videos_nav' => ['yes']
        ],
      ]
    );

    $this->add_control(
      'setting_layout_videos_dots',
      [
        'label' => esc_attr__('Setting dots', 'fel'),
        'type' => Controls_Manager::HEADING,
        'condition' => [
          'layout_grid' => ['slider1', 'slider2', 'tab'],
          'layout_videos_dots' => ['yes']
        ],
      ]
    );

    $this->add_responsive_control(
      'size_dots',
      [
        'label' => esc_html__('Size dots', 'fel'),
        'type' => Controls_Manager::SLIDER,
        'default' => [
          'size' => 13,
        ],
        'range' => [
          'px' => [
            'min' => 13,
            'max' => 100,
          ],
        ],
        'selectors' => [
          '{{WRAPPER}} .owl-carousel.fel-ytWrap__content .owl-dot' => 'width: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}};',
          '{{WRAPPER}} .fel-ytWrap__content.fel-ytWrap__tabContent .owl-carousel .owl-dot' => 'width: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}};'
        ],
        'condition' => [
          'layout_grid' => ['slider1', 'slider2', 'tab'],
          'layout_videos_dots' => ['yes'],
        ],
      ]
    );

    $this->add_responsive_control(
      'dots_radius',
      [
        'label' => esc_html__('Dots radius', 'fel'),
        'type' => Controls_Manager::DIMENSIONS,
        'default' => [
          'top' => '3',
          'right' => '3',
          'bottom' => '3',
          'left' => '3',
        ],
        'range' => [
          'px' => [
            'min' => 0,
            'max' => 1000,
          ],
        ],
        'selectors' => [
          '{{WRAPPER}} .owl-carousel.fel-ytWrap__content .owl-dot' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
          '{{WRAPPER}} .fel-ytWrap__content.fel-ytWrap__tabContent .owl-carousel .owl-dot' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
        'condition' => [
          'layout_grid' => ['slider1', 'slider2', 'tab'],
          'layout_videos_dots' => ['yes']
        ],
      ]
    );

    $this->add_control('dots_color',
      [
        'label' => esc_html__('Dots color', 'fel'),
        'type' => Controls_Manager::COLOR,
        'default' => '#000',
        'selectors' => [
          '{{WRAPPER}} .owl-carousel.fel-ytWrap__content .owl-dot' => 'background-color: {{VALUE}};',
          '{{WRAPPER}} .fel-ytWrap__content.fel-ytWrap__tabContent .owl-carousel .owl-dot' => 'background-color: {{VALUE}};',
        ],
        'condition' => [
          'layout_grid' => ['slider1', 'slider2', 'tab'],
          'layout_videos_dots' => ['yes']
        ],
      ]
    );

    $this->add_control('dots_color_hover',
      [
        'label' => esc_html__('Dots color hover', 'fel'),
        'type' => Controls_Manager::COLOR,
        'default' => '#fff000',
        'selectors' => [
          '{{WRAPPER}} .owl-carousel.fel-ytWrap__content .owl-dot:hover' => 'background-color: {{VALUE}};',
          '{{WRAPPER}} .owl-carousel.fel-ytWrap__content .owl-dot.active' => 'background-color: {{VALUE}};',
          '{{WRAPPER}} .fel-ytWrap__content.fel-ytWrap__tabContent .owl-carousel .owl-dot:hover' => 'background-color: {{VALUE}};',
          '{{WRAPPER}} .fel-ytWrap__content.fel-ytWrap__tabContent .owl-carousel .owl-dot.active' => 'background-color: {{VALUE}};',
        ],
        'condition' => [
          'layout_grid' => ['slider1', 'slider2', 'tab'],
          'layout_videos_dots' => ['yes']
        ],
      ]
    );

    $this->add_control(
      'dots_position',
      [
        'type' => Controls_Manager::SELECT,
        'label' => esc_html__('Dots position', 'fel'),
        'options' => array(
          'dleft_top' => esc_html__('Left top', 'fel'),
          'dleft_bottom' => esc_html__('Left bottom', 'fel'),
          'dright_top' => esc_html__('Right top', 'fel'),
          'dright_bottom' => esc_html__('Right bottom', 'fel'),
          'dtop_center' => esc_html__('Top center', 'fel'),
          'dbottom_center' => esc_html__('Bottom center', 'fel'),
        ),
        'default' => 'dbottom_center',
        'condition' => [
          'layout_grid' => ['slider1', 'slider2', 'tab'],
          'layout_videos_dots' => ['yes']
        ],
      ]
    );

    $this->add_responsive_control(
      'dots_position_dis2button',
      [
        'label' => esc_html__('Distion two dots', 'fel'),
        'type' => Controls_Manager::SLIDER,
        'default' => [
          'size' => 5,
        ],
        'range' => [
          'px' => [
            'min' => 5,
            'max' => 100,
          ],
        ],
        'selectors' => [
          '{{WRAPPER}} .owl-dots .owl-dot' => 'margin: 0 {{SIZE}}{{UNIT}};',
        ],
        'condition' => [
          'layout_grid' => ['slider1', 'slider2', 'tab'],
          'layout_videos_dots' => ['yes'],
        ],
      ]
    );

    $this->add_responsive_control(
      'dots_position_topcenter1',
      [
        'label' => esc_html__('Top position', 'fel'),
        'type' => Controls_Manager::SLIDER,
        'default' => [
          'size' => -30,
        ],
        'range' => [
          'px' => [
            'min' => -100,
            'max' => 100,
          ],
        ],
        'selectors' => [
          '{{WRAPPER}} .owl-dots' => 'margin-top: {{SIZE}}{{UNIT}};',
        ],
        'condition' => [
          'layout_grid' => ['slider1', 'slider2', 'tab'],
          'layout_videos_dots' => ['yes'],
        ],
      ]
    );

    $this->end_controls_section();

    $this->start_controls_section(
      'section_preloader',
      [
        'label' => esc_html__('Preloader', 'fel'),
        'tab' => Controls_Manager::TAB_SETTINGS,
      ]
    );

    $this->add_control(
      'setting_preloader',
      [
        'type' => Controls_Manager::SELECT,
        'label' => esc_html__('Choose a layout for Preloader', 'fel'),
        'options' => array(
          'style1' => esc_html__('Style 1', 'fel'),
          'style2' => esc_html__('Style 2', 'fel'),
          'style3' => esc_html__('Style 3', 'fel'),
          'style4' => esc_html__('Style 4', 'fel'),
          'style5' => esc_html__('Style 5', 'fel'),
          'style6' => esc_html__('Style 6', 'fel'),
          'style7' => esc_html__('Style 7', 'fel'),
          'style8' => esc_html__('Style 8', 'fel'),
          'style9' => esc_html__('Style 9', 'fel'),
          'style10' => esc_html__('Style 10', 'fel'),
          'style11' => esc_html__('Style 11', 'fel'),
          'style12' => esc_html__('Style 12', 'fel'),
          'style13' => esc_html__('Style 13', 'fel'),
          'style14' => esc_html__('Style 14', 'fel'),
          'style15' => esc_html__('Style 15', 'fel'),
        ),
        'default' => 'style1',
      ]
    );

    $this->end_controls_section();
  }

  function ytInfo()
  {
    $this->start_controls_section(
      'section_youtube_info',
      [
        'label' => esc_html__('Video Infomation', 'fel'),
      ]
    );

    $this->add_control(
      'yt_info_display',
      [
        'label' => esc_attr__('Display title', 'fel'),
        'type' => Controls_Manager::HEADING,
        'separator' => 'before'
      ]
    );

    $this->add_control(
      'video_position',
      [
        'label' => esc_html__('After title?', 'fel'),
        'type' => Controls_Manager::SWITCHER,
        'label_on' => esc_html__('Yes', 'fel'),
        'label_off' => esc_html__('No', 'fel'),
        'return_value' => 'yes',
        'default' => 'no',
      ]
    );

    $this->add_control(
      'yt_info_duration',
      [
        'label' => esc_attr__('Display duration', 'fel'),
        'type' => Controls_Manager::HEADING,
      ]
    );

    $this->add_control(
      'display_duration',
      [
        'label' => esc_html__('Youtube post?', 'fel'),
        'type' => Controls_Manager::SWITCHER,
        'label_on' => esc_html__('Yes', 'fel'),
        'label_off' => esc_html__('No', 'fel'),
        'return_value' => 'yes',
        'default' => 'yes',
      ]
    );

    $this->add_control(
      'yt_info_expert',
      [
        'label' => esc_attr__('Expert', 'fel'),
        'type' => Controls_Manager::HEADING,
      ]
    );

    $this->add_control(
      'display_excerpt',
      [
        'label' => esc_html__('YouTube video?', 'fel'),
        'type' => Controls_Manager::SWITCHER,
        'label_on' => esc_html__('Yes', 'fel'),
        'label_off' => esc_html__('No', 'fel'),
        'return_value' => 'yes',
        'default' => 'yes',
      ]
    );

    $this->add_control(
      'yt_info_else',
      [
        'label' => esc_attr__('Display else', 'fel'),
        'type' => Controls_Manager::HEADING,
        'separator' => 'before'
      ]
    );

    $this->add_control(
      'display_channel',
      [
        'label' => esc_html__('Channel name for each YouTube video?', 'fel'),
        'type' => Controls_Manager::SWITCHER,
        'label_on' => esc_html__('Yes', 'fel'),
        'label_off' => esc_html__('No', 'fel'),
        'return_value' => 'yes',
        'default' => 'yes',
      ]
    );

    $this->add_control(
      'display_date',
      [
        'label' => esc_html__('Posted date for the YouTube video?', 'fel'),
        'type' => Controls_Manager::SWITCHER,
        'label_on' => esc_html__('Yes', 'fel'),
        'label_off' => esc_html__('No', 'fel'),
        'return_value' => 'yes',
        'default' => 'yes',
      ]
    );

    $this->add_control(
      'display_comments',
      [
        'label' => esc_html__('Comments for each youtube post?', 'fel'),
        'type' => Controls_Manager::SWITCHER,
        'label_on' => esc_html__('Yes', 'fel'),
        'label_off' => esc_html__('No', 'fel'),
        'return_value' => 'yes',
        'default' => 'yes',
      ]
    );

    $this->add_control(
      'display_views',
      [
        'label' => esc_html__('Views count for the youtube post?', 'fel'),
        'type' => Controls_Manager::SWITCHER,
        'label_on' => esc_html__('Yes', 'fel'),
        'label_off' => esc_html__('No', 'fel'),
        'return_value' => 'yes',
        'default' => 'yes',
      ]
    );

    $this->add_control(
      'display_likes',
      [
        'label' => esc_html__('Likes count for the youtube post?', 'fel'),
        'type' => Controls_Manager::SWITCHER,
        'label_on' => esc_html__('Yes', 'fel'),
        'label_off' => esc_html__('No', 'fel'),
        'return_value' => 'yes',
        'default' => 'yes',
      ]
    );

    $this->end_controls_section();
  }

  function ytAPI()
  {
    $this->start_controls_section(
      'section_youtube_api',
      [
        'label' => esc_html__('YouTube API', 'fel'),
      ]
    );

    $this->add_control(
      'setting_youtube_api',
      [
        'label' => esc_attr__('Api', 'fel'),
        'type' => Controls_Manager::HEADING,
      ]
    );

    $this->add_control(
      'youtube_api_key', [
        'type' => Controls_Manager::TEXT,
        "description" => esc_html__("Your Key Api from Youtube API.", "fel"),
        "label" => esc_html__("API Key", "fel"),
        'default' => ''
      ]
    );

    $this->add_control(
      'setting_youtube_resource',
      [
        'label' => esc_attr__('Source', 'fel'),
        'type' => Controls_Manager::HEADING,
        'separator' => 'before'
      ]
    );

    $this->add_control(
      'youtube_source',
      [
        'type' => Controls_Manager::SELECT,
        'label' => esc_html__('YouTube source', 'fel'),
        'description' => esc_html__('Specify the YouTube source to display in the grid. Ensure YouTube API key is provided in the Social API before', 'fel'),
        'options' => array(
          'channel' => esc_html__('Channel', 'fel'),
          'playlist' => esc_html__('Playlist', 'fel'),
          'videos' => esc_html__('Videos', 'fel')
        ),
        'default' => 'channel',
      ]
    );

    $this->add_control(
      'youtube_channel',
      [
        'type' => Controls_Manager::TEXT,
        'label' => esc_html__('YouTube Channel', 'fel'),
        'description' => esc_html__('Enter the YouTube Channel ID. To find your YouTube Channel ID, ', 'fel') . ' <a target="_blank" href="https://stackoverflow.com/questions/14366648/how-can-i-get-a-channel-id-from-youtube">' . esc_html__('visit page.', 'fel') . '</a>',
        'condition' => [
          'youtube_source' => ['channel']
        ],
        'dynamic' => [
          'active' => true,
          'categories' => [
            TagsModule::POST_META_CATEGORY,
          ],
        ],
      ]
    );

    $this->add_control(
      'youtube_playlists',
      [
        'type' => Controls_Manager::TEXT,
        'label' => esc_html__('YouTube Playlist', 'fel'),
        'description' => esc_html__('Enter the Playlists ID', 'fel'),
        'condition' => [
          'layout_grid' => ['tab']
        ],
      ]
    );

    $this->add_control(
      'youtube_playlists_txt',
      [
        'type' => Controls_Manager::TEXT,
        'label' => esc_html__('YouTube Playlists Name', 'fel'),
        'description' => esc_html__('Enter the Show Name to playlist', 'fel'),
        'condition' => [
          'layout_grid' => ['tab']
        ],
      ]
    );

    $this->add_control(
      'youtube_order',
      [
        'type' => Controls_Manager::SELECT,
        'label' => esc_html__('Order By', 'fel'),
        'description' => esc_html__('Specify the sort order of the videos', 'fel'),
        'options' => array(
          'date' => esc_html__('Date', 'fel'),
          'title' => esc_html__('Title', 'fel'),
//          'viewCount' => esc_html__('Number of Views', 'fel')
        ),
        'condition' => [
          'youtube_source' => ['channel']
        ],
        'default' => 'date'
      ]
    );

    $this->add_control(
      'youtube_playlist',
      [
        'type' => Controls_Manager::TEXT,
        'label' => esc_html__('YouTube Playlist', 'fel'),
        'description' => esc_html__('Enter the YouTube playlist ID. To know how to find your YouTube playlist ID, ', 'fel') . ' <a target="_blank" href="https://www.youtube.com/watch?v=yf-W4YT6WIk">' . __('watch video.', 'fel') . '</a>',
        'condition' => [
          'youtube_source' => ['playlist']
        ],
        'dynamic' => [
          'active' => true,
          'categories' => [
            TagsModule::POST_META_CATEGORY,
          ],
        ],
      ]
    );

    $this->add_control(
      'youtube_videos',
      [
        'type' => Controls_Manager::TEXTAREA,
        'label' => esc_html__('YouTube Videos', 'fel'),
        'description' => esc_html__('Specify a comma separated list of video IDs. (ex. bqHNxfarW6E, MRzeLDkWT1c, bYAUx40dDFI)', 'fel'),
        'condition' => [
          'youtube_source' => ['videos']
        ],
        'dynamic' => [
          'active' => true,
          'categories' => [
            TagsModule::POST_META_CATEGORY,
          ],
        ],
      ]
    );

    $this->end_controls_section();
  }

  /**
   * Render oEmbed widget output on the frontend.
   *
   * Written in PHP and used to generate the final HTML.
   *
   * @since 1.0.0
   * @access protected
   */
  protected function render()
  {
    $settings = $this->get_settings_for_display();
    $channel_id = $settings['youtube_channel'];
    $channel_info = null;
    $youtube_client = $settings['youtube_api_key'];
    $columns = 'fel-ytWrap__content--col' . $settings['per_line']; //chua respon video
    $layout_video = $settings['layout_video'];
    $layout_videos = $settings['layout_videos'];
    $icon_prev = $settings['icon_prev'];
    $icon_next = $settings['icon_next'];
    $layout_videos_nav = $settings['layout_videos_nav'];
    $layout_videos_dots = $settings['layout_videos_dots'];
    $distant_video = 0;
    if (!empty($settings['layout_videos_distant'])) {
      $distant_video = $settings['layout_videos_distant']["size"];
    }    
    $nav_position = $settings['nav_position'];
    $dots_position = $settings['dots_position'];
    $title = '';
    $logo = '';
    $banner = '';

    if ($layout_videos_nav != "no")
      $layout_videos_nav = 'owl-nav-show';
    if ($layout_videos_dots != "no")
      $layout_videos_dots = 'owl-dots-show';

    if (!empty($channel_id))
      $channel_info = self::queryYT('channels', 'id', $channel_id, $youtube_client, 'id,contentDetails,snippet,brandingSettings,statistics', $layout_videos["size"]);

    if ($settings['layout_grid'] == 'mansory') :
      if ($settings['youtube_source'] == 'channel') :
        if (!empty($channel_id)) :
          //get all id videos
          $channel_videos = self::queryYT('search', 'channelId', $channel_id, $youtube_client, 'snippet,id', '', 0, $settings['youtube_order'], $layout_videos["size"]);

          $channel_videos_sorted = $channel_videos->items;
          if ($settings['youtube_order'] == "date")
            usort($channel_videos_sorted, function ($a, $b) { //Sort the array using a user defined function
              return $a->snippet->publishedAt > $b->snippet->publishedAt ? 1 : -1; //Compare the scores
            });
          elseif ($settings['youtube_order'] == "title")
            usort($channel_videos_sorted, function ($a, $b) { //Sort the array using a user defined function
              return $a->snippet->title > $b->snippet->title ? 1 : -1; //Compare the scores
            });

          if (isset($channel_info->items[0]) && !empty($channel_info->items[0])) :
            $logo = $channel_info->items[0]->snippet->thumbnails->default->url;
            if (isset($channel_info->items[0]->brandingSettings->image))
              $banner = $channel_info->items[0]->brandingSettings->image->bannerExternalUrl;
            $title = $channel_info->items[0]->snippet->title;
            $caption = $channel_info->items[0]->snippet->description;
            $viewCount = $channel_info->items[0]->statistics->viewCount;
            $videoCount = $channel_info->items[0]->statistics->videoCount;
            ?>

            <div class="fel-ytWrap">
            <div class="fel-ytWrap__head">
              <div class="fel-ytWrap__banner">
                <img src="<?php echo esc_url($banner); ?>" alt="">
              </div>
              <div class="fel-ytWrap__detail">
                <div class="fel-ytWrap__logo">
                  <a href="<?php echo esc_url('https://www.youtube.com/channel/' . esc_attr($channel_id) . '/'); ?>"
                     target="_blank">

                    <img src="<?php echo esc_url($logo); ?>" alt="<?php echo esc_html($title); ?>">

                  </a>
                </div>

                <div class="fel-ytWrap__info">
                  <h3>
                    <a href="<?php echo esc_url('https://www.youtube.com/channel/' . esc_attr($channel_id) . '/'); ?>"
                       target="_blank"><?php echo esc_html($title); ?></a>
                  </h3>


                  <div class="fel-ytWrap__stats">

                    <span><?php echo esc_html(self::fel_format($videoCount)) . ' ' . esc_html__('videos', 'fel'); ?></span>
                    ,
                    <span><?php echo esc_html(self::fel_format($viewCount)) . ' ' . esc_html__('views', 'fel'); ?></span>

                  </div>

                  <div class="fel-ytWrap__subscribe">
                    <script src="https://apis.google.com/js/platform.js"></script>
                    <div class="g-ytsubscribe"
                         data-channelid="<?php echo esc_attr($channel_id); ?>"
                         data-layout="default"
                         data-count="default"></div>
                  </div>
                </div>

                <p><?php echo esc_html($caption); ?></p>
              </div>
            </div>
          <div class="fel-ytWrap__content fel-ytWrap__content--masory <?php echo esc_attr($columns); ?>"
               data-gutter="0">
            <?php
            //get info video
            foreach ($channel_videos_sorted as $video123) {
              $video_title = esc_attr($video123->snippet->title);
              $video_desc = esc_attr($video123->snippet->description);
              $video_detail = '';
              if (isset($video123->id->videoId))
                $video_detail = self::fel_getDetails($video123->id->videoId, $youtube_client);
              $VidDuration = "";
              if (isset($video_detail['items'][0]['contentDetails']))
                $VidDuration = $video_detail['items'][0]['contentDetails']['duration'];

              $pattern = '/PT(\d+)M(\d+)S/';
              preg_match($pattern, $VidDuration, $matches);
              $time = '';
              if ($matches)
                $time = $matches[1] . ':' . $matches[2];

              ?>

              <div class="fel-ytWrap__item">
              <div class="fel-ytWrap__meta">
                <?php if ($settings['display_channel'] == "yes") : ?>
                  <div class="fel-ytWrap__avarta">
                    <img src="<?php echo esc_url($logo); ?>" alt="<?php echo esc_html($title); ?>">
                    <span><?php echo esc_html($title); ?></span>
                  </div>
                <?php endif; ?>

                <?php if ($settings['display_date'] == "yes") : ?>
                  <div class="fel-ytWrap__date">
                    <?php echo self::fel_calDate($video123->snippet->publishedAt, date("Y-m-d H:i:s")) ?>
                  </div>
                <?php endif; ?>
              </div>

              <div class="fel-ytWrap__item__info">
              <?php if ($settings['video_position'] == "yes") : ?>
              <<?php echo $settings['item_title_tag'] ?> class="fel-ytTitle"><a
                href="<?php echo esc_url("https://www.youtube.com/watch?v=" . $video123->id->videoId); ?>"
                title="<?php echo esc_attr($video_title); ?>" target="_blank"><?php echo esc_attr($video_title); ?></a>
              </<?php echo $settings['item_title_tag'] ?>>
            <?php endif; ?>

              <div class="fel-ytWrap__video">

                <?php if ($layout_video == 'videoinline') : ?>
                  <iframe width="560" height="315"
                          src="https://www.youtube.com/embed/<?php echo esc_attr($video123->id->videoId); ?>"
                          frameborder="0"
                          allow="accelerometer; autoplay; encrypted-media; gyroscope; picture-in-picture"
                          allowfullscreen></iframe>

                <?php elseif ($layout_video == 'newtab') : ?>
                  <a href="<?php echo esc_url("https://www.youtube.com/watch?v=" . $video123->id->videoId); ?>"
                     title="<?php echo esc_attr($video_title); ?>" target="_blank">
                    <img src="<?php echo $video123->snippet->thumbnails->high->url; ?>"
                         alt="<?php echo esc_attr($video_title); ?>">
                    <?php if ($settings['display_duration'] == "yes") : ?>
                      <span
                        class="fel-ytWrap__time"><?php echo esc_attr($time); ?></span>
                    <?php endif; ?>
                    <span class="fel-ytWrap__icon"><i class="eicon-play"></i></span>
                  </a>
                <?php else: ?>
                  <div data-id="<?php echo $video123->id->videoId; ?>" class="fel-ytShowPopup">
                    <img src="<?php echo $video123->snippet->thumbnails->high->url; ?>"
                         alt="<?php echo esc_attr($video_title); ?>">
                    <?php if ($settings['display_duration'] == "yes") : ?>
                      <span
                        class="fel-ytWrap__time"><?php echo esc_attr($time); ?></span>
                    <?php endif; ?>
                    <span class="fel-ytWrap__icon"><i class="eicon-play"></i></span>
                  </div>
                <?php endif; ?>
              </div>

              <?php if ($settings['video_position'] == "no") : ?>
                <<?php echo $settings['item_title_tag'] ?> class="fel-ytTitle"><a
                  href="<?php echo esc_url("https://www.youtube.com/watch?v=" . $video123->id->videoId); ?>"
                  title="<?php echo esc_attr($video_title); ?>"
                  target="_blank"><?php echo esc_attr($video_title); ?></a>
                </<?php echo $settings['item_title_tag'] ?>>
              <?php endif; ?>
              <?php if ($settings['display_excerpt'] == "yes") : ?>
                <p><?php echo esc_attr($video_desc); ?></p>
              <?php endif;
              if (isset($video_detail['items']))
                self::viewCountComments($settings['display_views'], $settings['display_likes'], $settings['display_comments'],
                  $video_detail['items'][0]["statistics"]["viewCount"], $video_detail['items'][0]["statistics"]["likeCount"], $video_detail['items'][0]["statistics"]["commentCount"]);

              ?>

              </div>
              </div>

              <?php
            }
            ?>

            </div>

            <div class="fel-ytLoader">
              <?php self::preloader($settings['setting_preloader']); ?>
            </div>

            <div class="fel-ytEvent">

              <?php self::ytLoader('style1', $channel_videos->nextPageToken, $settings['youtube_playlist'], $layout_videos["size"], $logo, '',
                esc_html($title), $settings['youtube_order'], $youtube_client,
                $settings['video_position'], $settings['display_duration'], $settings['display_excerpt'], $settings['display_channel'],
                $settings['display_date'], $settings['display_comments'], $settings['display_likes'], $settings['display_views'],
                $channel_id, $layout_video); ?>

              <div class="fel-ytNextpage"><?php //echo $channel_videos->nextPageToken;
                ?></div>
            </div>

            <?php
          endif;
        endif;
      elseif ($settings['youtube_source'] == 'playlist') :
        if ($settings['youtube_playlist'] != "") :
          $channel_videos = self::queryYTPlaylist('playlistItems', $settings['youtube_playlist'], $youtube_client, '', 0, $settings['youtube_order'], $layout_videos["size"]);
          $channel_videos_sorted = $channel_videos->items;
          if ($settings['youtube_order'] == "date")
            usort($channel_videos_sorted, function ($a, $b) { //Sort the array using a user defined function
              return $a->snippet->publishedAt > $b->snippet->publishedAt ? 1 : -1; //Compare the scores
            });
          elseif ($settings['youtube_order'] == "title")
            usort($channel_videos_sorted, function ($a, $b) { //Sort the array using a user defined function
              return $a->snippet->title > $b->snippet->title ? 1 : -1; //Compare the scores
            });
          
          ?>

          <div class="fel-ytWrap">
        <div class="fel-ytWrap__content fel-ytWrap__content--masory <?php echo esc_attr($columns); ?>" data-gutter="0">
          <?php
          //get info video
          foreach ($channel_videos_sorted as $video123) {
            $video_title = esc_attr($video123->snippet->title);
            $video_desc = esc_attr($video123->snippet->description);
            $video_detail = self::fel_getDetails($video123->contentDetails->videoId, $youtube_client);
            $VidDuration = "";
            foreach ($video_detail['items'] as $vidTime) {
              $VidDuration = $vidTime['contentDetails']['duration'];
            }

            $pattern = '/PT(\d+)M(\d+)S/';
            preg_match($pattern, $VidDuration, $matches);
            $time = '';
            if ($matches)
              $time = $matches[1] . ':' . $matches[2];
            ?>

            <div class="fel-ytWrap__item">
            <div class="fel-ytWrap__item__info">
            <?php if ($settings['video_position'] == "yes") : ?>
            <<?php echo $settings['item_title_tag'] ?> class="fel-ytTitle"><a
              href="<?php echo esc_url("https://www.youtube.com/watch?v=" . $video123->id->videoId); ?>"
              title="<?php echo esc_attr($video_title); ?>" target="_blank"><?php echo esc_attr($video_title); ?></a>
            </<?php echo $settings['item_title_tag'] ?>>
          <?php endif; ?>

            <div class="fel-ytWrap__video">

              <?php if ($layout_video == 'videoinline') : ?>
                <iframe width="560" height="315"
                        src="https://www.youtube.com/embed/<?php echo esc_attr($video123->contentDetails->videoId); ?>"
                        frameborder="0"
                        allow="accelerometer; autoplay; encrypted-media; gyroscope; picture-in-picture"
                        allowfullscreen></iframe>
              <?php elseif ($layout_video == 'newtab') : ?>
                <a
                  href="<?php echo esc_url("https://www.youtube.com/watch?v=" . $video123->contentDetails->videoId); ?>"
                  title="<?php echo esc_attr($video_title); ?>" target="_blank">
                  <img src="<?php echo $video123->snippet->thumbnails->high->url; ?>"
                       alt="<?php echo esc_attr($video_title); ?>">
                  <?php if ($settings['display_duration'] == "yes") : ?>
                    <span
                      class="fel-ytWrap__time"><?php echo esc_attr($time); ?></span>
                  <?php endif; ?>
                  <span class="fel-ytWrap__icon"><i class="eicon-play"></i></span>
                </a>
              <?php else: ?>

                <div data-id="<?php echo $video123->contentDetails->videoId; ?>" class="fel-ytShowPopup">
                  <img src="<?php echo $video123->snippet->thumbnails->high->url; ?>"
                       alt="<?php echo esc_attr($video_title); ?>">
                  <?php if ($settings['display_duration'] == "yes") : ?>
                    <span
                      class="fel-ytWrap__time"><?php echo esc_attr($time); ?></span>
                  <?php endif; ?>
                  <span class="fel-ytWrap__icon"><i class="eicon-play"></i></span>
                </div>
              <?php endif; ?>
            </div>
            <?php if ($settings['video_position'] == "no") : ?>
              <<?php echo $settings['item_title_tag'] ?> class="fel-ytTitle"><a
                href="<?php echo esc_url("https://www.youtube.com/watch?v=" . $video123->contentDetails->videoId); ?>"
                title="<?php echo esc_attr($video_title); ?>" target="_blank"><?php echo esc_attr($video_title); ?></a>
              </<?php echo $settings['item_title_tag'] ?>>
            <?php endif; ?>
            <?php if ($settings['display_excerpt'] == "yes") : ?>
              <p><?php echo esc_attr($video_desc); ?></p>
            <?php endif;
            if (isset($video_detail['items']))
              self::viewCountComments($settings['display_views'], $settings['display_likes'], $settings['display_comments'],
                $video_detail['items'][0]["statistics"]["viewCount"], $video_detail['items'][0]["statistics"]["likeCount"], $video_detail['items'][0]["statistics"]["commentCount"]);
            ?>
            </div>
            </div>

            <?php
          }
          ?>

          </div>

          <div class="fel-ytLoader">
            <?php self::preloader($settings['setting_preloader']); ?>
          </div>

          <div class="fel-ytEvent fel-ytEvent--playList">

            <?php self::ytLoader('style2', $channel_videos->nextPageToken, $settings['youtube_playlist'], '10', $logo, '', esc_html($title), $settings['youtube_order'], $youtube_client,
              $settings['video_position'], $settings['display_duration'], $settings['display_excerpt'], $settings['display_channel'],
              $settings['display_date'], $settings['display_comments'], $settings['display_likes'], $settings['display_views'], $layout_video); ?>

            <div class="fel-ytNextpage"><?php echo $channel_videos->nextPageToken;
              ?></div>
          </div>

          <?php
        endif;
      elseif ($settings['youtube_source'] == 'videos') :
        if ($settings['youtube_videos'] != "") :
          $channel_videos = self::queryYTVideos($settings['youtube_videos'], $youtube_client, '', 0);
          ?>

          <div class="fel-ytWrap">
        <div
          class="fel-ytWrap__content fel-ytWrap__content--masory <?php echo esc_attr($columns); ?> <?php echo 'ver-' . $settings['youtube_source']; ?>"
          data-gutter="15">
          <?php
          //get info video
          foreach ($channel_videos->items as $video123) {
            $video_title = esc_attr($video123->snippet->title);
            $video_desc = esc_attr($video123->snippet->description);
            $VidDuration = $video123->contentDetails->duration;

            $pattern = '/PT(\d+)M(\d+)S/';
            preg_match($pattern, $VidDuration, $matches);
            $time = $matches[1] . ':' . $matches[2];
            ?>

            <div class="fel-ytWrap__item">
            <div class="fel-ytWrap__item__info">
            <?php if ($settings['video_position'] == "yes") : ?>
            <<?php echo $settings['item_title_tag'] ?> class="fel-ytTitle"><a
              href="<?php echo esc_url("https://www.youtube.com/watch?v=" . $video123->id); ?>"
              title="<?php echo esc_attr($video_title); ?>" target="_blank"><?php echo esc_attr($video_title); ?></a>
            </<?php echo $settings['item_title_tag'] ?>>
          <?php endif; ?>

            <div class="fel-ytWrap__video">
              <?php if ($layout_video == 'videoinline') : ?>
                <iframe width="560" height="315"
                        src="https://www.youtube.com/embed/<?php echo esc_attr($video123->id); ?>"
                        frameborder="0"
                        allow="accelerometer; autoplay; encrypted-media; gyroscope; picture-in-picture"
                        allowfullscreen></iframe>
              <?php elseif ($layout_video == 'newtab') : ?>
                <a href="<?php echo esc_url("https://www.youtube.com/watch?v=" . $video123->id); ?>"
                   title="<?php echo esc_attr($video_title); ?>" target="_blank">
                  <img src="<?php echo $video123->snippet->thumbnails->high->url; ?>"
                       alt="<?php echo esc_attr($video_title); ?>">
                  <?php if ($settings['display_duration'] == "yes") : ?>
                    <span
                      class="fel-ytWrap__time"><?php echo esc_attr($time); ?></span>
                  <?php endif; ?>
                  <span class="fel-ytWrap__icon"><i class="eicon-play"></i></span>
                </a>
              <?php else: ?>

                <div data-id="<?php echo $video123->id; ?>" class="fel-ytShowPopup">
                  <img src="<?php echo $video123->snippet->thumbnails->high->url; ?>"
                       alt="<?php echo esc_attr($video_title); ?>">
                  <?php if ($settings['display_duration'] == "yes") : ?>
                    <span
                      class="fel-ytWrap__time"><?php echo esc_attr($time); ?></span>
                  <?php endif; ?>
                  <span class="fel-ytWrap__icon"><i class="eicon-play"></i></span>
                </div>

              <?php endif; ?>
            </div>
            <?php if ($settings['video_position'] == "no") : ?>
              <<?php echo $settings['item_title_tag'] ?> class="fel-ytTitle"><a
                href="<?php echo esc_url("https://www.youtube.com/watch?v=" . $video123->id); ?>"
                title="<?php echo esc_attr($video_title); ?>" target="_blank"><?php echo esc_attr($video_title); ?></a>
              </<?php echo $settings['item_title_tag'] ?>>
            <?php endif; ?>
            <?php if ($settings['display_excerpt'] == "yes") : ?>
              <p><?php echo esc_attr($video_desc); ?></p>
            <?php endif; ?>

            <?php
            if (isset($video_detail['items']))
              self::viewCountComments($settings['display_views'], $settings['display_likes'], "no",
                $video123->statistics->viewCount, $video123->statistics->likeCount);
            ?>

            </div>
            </div>

            <?php
          }
          ?>

          </div>

          <?php
        endif;
      endif;
    elseif ($settings['layout_grid'] == 'slider1' || $settings['layout_grid'] == 'slider2'):
      if (!empty($channel_id)) :
        //get all id videos
        $channel_videos = self::queryYT('search', 'channelId', $channel_id, $youtube_client, 'snippet,id', '', 0, $settings['youtube_order']);

        $channel_videos_sorted = $channel_videos->items;
        if ($settings['youtube_order'] == "date")
          usort($channel_videos_sorted, function ($a, $b) { //Sort the array using a user defined function
            return $a->snippet->publishedAt > $b->snippet->publishedAt ? 1 : -1; //Compare the scores
          });
        elseif ($settings['youtube_order'] == "title")
          usort($channel_videos_sorted, function ($a, $b) { //Sort the array using a user defined function
            return $a->snippet->title > $b->snippet->title ? 1 : -1; //Compare the scores
          });

        if (isset($channel_info->items[0]) && !empty($channel_info->items[0])) :
          $logo = $channel_info->items[0]->snippet->thumbnails->default->url;
          if (isset($channel_info->items[0]->brandingSettings->image))
            $banner = $channel_info->items[0]->brandingSettings->image->bannerTabletHdImageUrl;
          $title = $channel_info->items[0]->snippet->title;
          $caption = $channel_info->items[0]->snippet->description;
          $viewCount = $channel_info->items[0]->statistics->viewCount;
          $videoCount = $channel_info->items[0]->statistics->videoCount;
          ?>

          <div class="fel-ytWrap">
          <div class="fel-ytWrap__head">
            <div class="fel-ytWrap__banner">
              <img src="<?php echo esc_url($banner); ?>" alt="">
            </div>
            <div class="fel-ytWrap__detail">
              <div class="fel-ytWrap__logo">
                <a href="<?php echo esc_url('https://www.youtube.com/channel/' . esc_attr($channel_id) . '/'); ?>"
                   target="_blank">

                  <img src="<?php echo esc_url($logo); ?>" alt="<?php echo esc_html($title); ?>">

                </a>
              </div>

              <div class="fel-ytWrap__info">
                <h3>
                  <a href="<?php echo esc_url('https://www.youtube.com/channel/' . esc_attr($channel_id) . '/'); ?>"
                     target="_blank"><?php echo esc_html($title); ?></a>
                </h3>


                <div class="fel-ytWrap__stats">

                  <span><?php echo esc_html(self::fel_format($videoCount)) . ' ' . esc_html__('videos', 'fel'); ?></span>
                  ,
                  <span><?php echo esc_html(self::fel_format($viewCount)) . ' ' . esc_html__('views', 'fel'); ?></span>

                </div>

                <div class="fel-ytWrap__subscribe">
                  <script src="https://apis.google.com/js/platform.js"></script>
                  <div class="g-ytsubscribe"
                       data-channelid="<?php echo esc_attr($channel_id); ?>"
                       data-layout="default"
                       data-count="default"></div>
                </div>
              </div>

              <p><?php echo esc_html($caption); ?></p>
            </div>
          </div>

        <div
          class="fel-ytWrap__content owl-carousel <?php echo esc_attr($columns); ?> <?php echo esc_attr($layout_videos_nav); ?> <?php echo esc_attr($layout_videos_dots); ?> <?php echo esc_attr($nav_position); ?> <?php echo esc_attr($dots_position); ?> "
          data-gutter="0" data-prev="<?php echo $icon_prev; ?>" data-next="<?php echo $icon_next; ?>"
          data-distant="<?php echo $distant_video; ?>"
          data-items="<?php echo $settings['per_line']; ?>">
          <?php
          //get info video
          $item = -1;
          foreach ($channel_videos_sorted as $video123) {
            $video_title = esc_attr($video123->snippet->title);
            $video_desc = esc_attr($video123->snippet->description);
            $video_detail = '';
            if (isset($video123->id->videoId))
              $video_detail = self::fel_getDetails($video123->id->videoId, $youtube_client);
            $VidDuration = "";
            if (isset($video_detail['items'][0]['contentDetails']))
              $VidDuration = $video_detail['items'][0]['contentDetails']['duration'];

            $pattern = '/PT(\d+)M(\d+)S/';
            preg_match($pattern, $VidDuration, $matches);
            $time = '';
            if ($matches)
              $time = $matches[1] . ':' . $matches[2];
            $item++;
            ?>

            <?php if ($item == 0 && $settings['layout_grid'] == "slider2") : ?>
              <div class="fel-ytWrap__item">
            <?php elseif ($settings['layout_grid'] != "slider2"): ?>
              <div class="fel-ytWrap__item">
            <?php endif; ?>

            <div class="fel-ytWrap__meta">
              <?php if ($settings['display_channel'] == "yes") : ?>
                <div class="fel-ytWrap__avarta">
                  <img src="<?php echo esc_url($logo); ?>" alt="<?php echo esc_html($title); ?>">
                  <span><?php echo esc_html($title); ?></span>
                </div>
              <?php endif; ?>

              <?php if ($settings['display_date'] == "yes") : ?>
                <div class="fel-ytWrap__date">
                  <?php echo self::fel_calDate($video123->snippet->publishedAt, date("Y-m-d H:i:s")) ?>
                </div>
              <?php endif; ?>
            </div>

            <div class="fel-ytWrap__item__info">
            <?php if ($settings['video_position'] == "yes") : ?>
            <<?php echo $settings['item_title_tag'] ?> class="fel-ytTitle"><a
              href="<?php echo esc_url("https://www.youtube.com/watch?v=" . $video123->id->videoId); ?>"
              title="<?php echo esc_attr($video_title); ?>" target="_blank"><?php echo esc_attr($video_title); ?></a>
            </<?php echo $settings['item_title_tag'] ?>>
          <?php endif; ?>

            <div class="fel-ytWrap__video">

              <?php if ($layout_video == 'videoinline') : ?>
                <iframe width="560" height="315"
                        src="https://www.youtube.com/embed/<?php echo esc_attr($video123->id->videoId); ?>"
                        frameborder="0"
                        allow="accelerometer; autoplay; encrypted-media; gyroscope; picture-in-picture"
                        allowfullscreen></iframe>

              <?php elseif ($layout_video == 'newtab') : ?>
                <a href="<?php echo esc_url("https://www.youtube.com/watch?v=" . $video123->id->videoId); ?>"
                   title="<?php echo esc_attr($video_title); ?>" target="_blank">
                  <img src="<?php echo $video123->snippet->thumbnails->high->url; ?>"
                       alt="<?php echo esc_attr($video_title); ?>">
                  <?php if ($settings['display_duration'] == "yes") : ?>
                    <span
                      class="fel-ytWrap__time"><?php echo esc_attr($time); ?></span>
                  <?php endif; ?>
                  <span class="fel-ytWrap__icon"><i class="eicon-play"></i></span>
                </a>
              <?php else: ?>
                <div data-id="<?php echo $video123->id->videoId; ?>" class="fel-ytShowPopup">
                  <img src="<?php echo $video123->snippet->thumbnails->high->url; ?>"
                       alt="<?php echo esc_attr($video_title); ?>">
                  <?php if ($settings['display_duration'] == "yes") : ?>
                    <span
                      class="fel-ytWrap__time"><?php echo esc_attr($time); ?></span>
                  <?php endif; ?>
                  <span class="fel-ytWrap__icon"><i class="eicon-play"></i></span>
                </div>
              <?php endif; ?>
            </div>

            <?php if ($settings['video_position'] == "no") : ?>
            <<?php echo $settings['item_title_tag'] ?> class="fel-ytTitle"><a
              href="<?php echo esc_url("https://www.youtube.com/watch?v=" . $video123->id->videoId); ?>"
              title="<?php echo esc_attr($video_title); ?>"
              target="_blank"><?php echo esc_attr($video_title); ?></a>
            </<?php echo $settings['item_title_tag'] ?>>
          <?php endif; ?>
            <?php if ($settings['display_excerpt'] == "yes") : ?>
              <p><?php echo esc_attr($video_desc); ?></p>
            <?php endif;
            if (isset($video_detail['items']))
              self::viewCountComments($settings['display_views'], $settings['display_likes'], $settings['display_comments'],
                $video_detail['items'][0]["statistics"]["viewCount"], $video_detail['items'][0]["statistics"]["likeCount"], $video_detail['items'][0]["statistics"]["commentCount"]);

            ?>

            </div>
            <?php if ($item == 1 && $settings['layout_grid'] == "slider2") : $item = -1; ?>
              </div>
            <?php elseif ($settings['layout_grid'] != "slider2"): ?>
              </div>
            <?php endif; ?>

            <?php
          }
          ?>

          </div>

          <?php
        endif;
      endif;
    elseif ($settings['layout_grid'] == 'tab'):
      if ($settings['youtube_playlists'] != "") :
        $chanels = explode(',', $settings['youtube_playlists']);
        $tab_name = explode(',', $settings['youtube_playlists_txt']); ?>
        <!--        //http://jsfiddle.net/voveson/8hv6tgax/25/-->
        <div class="fel-ytWrap">
        <div class="fel-ytWrap__headTab">
          <?php $iPoint = -1;
          foreach ($chanels as $chanel) : $iPoint++; ?>

            <span data-id="#content<?php echo $iPoint; ?>"><?php echo esc_attr($tab_name[$iPoint]); ?></span>

          <?php endforeach; ?>

        </div>
      <div
        class="fel-ytWrap__content fel-ytWrap__tabContent <?php echo esc_attr($columns); ?> <?php echo esc_attr($layout_videos_nav); ?> <?php echo esc_attr($layout_videos_dots); ?> <?php echo esc_attr($nav_position); ?> <?php echo esc_attr($dots_position); ?> "
        data-gutter="0" data-prev="<?php echo $icon_prev; ?>" data-next="<?php echo $icon_next; ?>"
        data-distant="<?php echo $distant_video; ?>"
        data-items="<?php echo $settings['per_line']; ?>">

        <?php $iPoint = -1;
        foreach ($chanels as $chanel) : $iPoint++; //content
          $channel_videos = self::queryYTPlaylist('playlistItems', $chanel, $youtube_client, '', 0, $settings['youtube_order'], $layout_videos["size"]);
          $channel_videos_sorted = $channel_videos->items;
          if ($settings['youtube_order'] == "date")
            usort($channel_videos_sorted, function ($a, $b) { //Sort the array using a user defined function
              return $a->snippet->publishedAt > $b->snippet->publishedAt ? 1 : -1; //Compare the scores
            });
          elseif ($settings['youtube_order'] == "title")
            usort($channel_videos_sorted, function ($a, $b) { //Sort the array using a user defined function
              return $a->snippet->title > $b->snippet->title ? 1 : -1; //Compare the scores
            });
          ?>

        <div id="content<?php echo $iPoint; ?>">
          <div class="owl-carousel">
          <?php
          //get info video
          foreach ($channel_videos_sorted as $video123) {
            $video_title = esc_attr($video123->snippet->title);
            $video_desc = esc_attr($video123->snippet->description);
            $video_detail = self::fel_getDetails($video123->contentDetails->videoId, $youtube_client);
            $VidDuration = "";
            foreach ($video_detail['items'] as $vidTime) {
              $VidDuration = $vidTime['contentDetails']['duration'];
            }

            $pattern = '/PT(\d+)M(\d+)S/';
            preg_match($pattern, $VidDuration, $matches);
            $time = '';
            if ($matches)
              $time = $matches[1] . ':' . $matches[2];
            ?>

            <div class="fel-ytWrap__item">
            <div class="fel-ytWrap__item__info">
            <?php if ($settings['video_position'] == "yes") : ?>
            <<?php echo $settings['item_title_tag'] ?> class="fel-ytTitle"><a
              href="<?php echo esc_url("https://www.youtube.com/watch?v=" . $video123->id->videoId); ?>"
              title="<?php echo esc_attr($video_title); ?>" target="_blank"><?php echo esc_attr($video_title); ?></a>
            </<?php echo $settings['item_title_tag'] ?>>
          <?php endif; ?>

            <div class="fel-ytWrap__video">

              <?php if ($layout_video == 'videoinline') : ?>
                <iframe width="560" height="315"
                        src="https://www.youtube.com/embed/<?php echo esc_attr($video123->contentDetails->videoId); ?>"
                        frameborder="0"
                        allow="accelerometer; autoplay; encrypted-media; gyroscope; picture-in-picture"
                        allowfullscreen></iframe>
              <?php elseif ($layout_video == 'newtab') : ?>
                <a
                  href="<?php echo esc_url("https://www.youtube.com/watch?v=" . $video123->contentDetails->videoId); ?>"
                  title="<?php echo esc_attr($video_title); ?>" target="_blank">
                  <img src="<?php echo $video123->snippet->thumbnails->high->url; ?>"
                       alt="<?php echo esc_attr($video_title); ?>">
                  <?php if ($settings['display_duration'] == "yes") : ?>
                    <span
                      class="fel-ytWrap__time"><?php echo esc_attr($time); ?></span>
                  <?php endif; ?>
                  <span class="fel-ytWrap__icon"><i class="eicon-play"></i></span>
                </a>
              <?php else: ?>

                <div data-id="<?php echo $video123->contentDetails->videoId; ?>" class="fel-ytShowPopup">
                  <img src="<?php echo $video123->snippet->thumbnails->high->url; ?>"
                       alt="<?php echo esc_attr($video_title); ?>">
                  <?php if ($settings['display_duration'] == "yes") : ?>
                    <span
                      class="fel-ytWrap__time"><?php echo esc_attr($time); ?></span>
                  <?php endif; ?>
                  <span class="fel-ytWrap__icon"><i class="eicon-play"></i></span>
                </div>
              <?php endif; ?>
            </div>
            <?php if ($settings['video_position'] == "no") : ?>
              <<?php echo $settings['item_title_tag'] ?> class="fel-ytTitle"><a
                href="<?php echo esc_url("https://www.youtube.com/watch?v=" . $video123->contentDetails->videoId); ?>"
                title="<?php echo esc_attr($video_title); ?>" target="_blank"><?php echo esc_attr($video_title); ?></a>
              </<?php echo $settings['item_title_tag'] ?>>
            <?php endif; ?>
            <?php if ($settings['display_excerpt'] == "yes") : ?>
              <p><?php echo esc_attr($video_desc); ?></p>
            <?php endif;
            if (isset($video_detail['items']))
              self::viewCountComments($settings['display_views'], $settings['display_likes'], $settings['display_comments'],
                $video_detail['items'][0]["statistics"]["viewCount"], $video_detail['items'][0]["statistics"]["likeCount"], $video_detail['items'][0]["statistics"]["commentCount"]);
            ?>
            </div>
            </div>

            <?php
          }
          ?>
          </div>
          </div>

        <?php endforeach; ?>

        </div>
        </div>

        <?php
      endif;
    endif;
    ?>

    <div class="fel-ytPopup">
      <span class="fel-ytClose"><i class="eicon-close"></i></span>

      <div class="fel-ytPopup__content">
        <iframe src="" frameborder="0"
                allow="accelerometer; autoplay; encrypted-media; gyroscope; picture-in-picture"></iframe>
      </div>
    </div>

    <div class="fel-ytOverlay"></div>

    <?php
  }

  function viewCountComments($is_view = "", $is_like = "", $is_comment = "", $view = "0", $count = "0", $commnets = "0")
  { ?>

    <div class="fel-ytWrap__details">
      <?php if ($is_view == "yes") : ?>
        <span
          class="fel-ytWrap__views"><span><?php echo number_format($view, 0, '.', ','); ?></span> <i
            class="eicon-preview-medium"></i></span>
      <?php endif; ?>
      <?php if ($is_like == "yes") : ?>
        <span
          class="fel-ytWrap__like"><span><?php echo number_format($count, 0, '.', ','); ?></span> <i
            class="eicon-facebook-like-box"></i></span>
      <?php endif; ?>
      <?php if ($is_comment == "yes") : ?>
        <span
          class="fel-ytWrap__comments"><span><?php echo number_format($commnets, 0, '.', ','); ?></span> <i
            class="eicon-comments"></i></span>
      <?php endif; ?>
    </div>
  <?php }

  function ytLoader($style = 'style1', $token = "", $playlist = "", $max = "10", $logo = "", $text = "", $title = "", $order = "", $key = "",
                    $display_title = "", $display_duration = "", $display_expert = "", $channel_name = "", $channel_date = "",
                    $channel_comments = "", $channel_likes = "", $channel_view = "", $channel = "", $layout = "")
  { ?>

    <buton class="fel-ytLoadMore" data-token="<?php echo esc_attr($token); ?>"
           data-display_title="<?php echo esc_attr($display_title); ?>"
           data-display_duration="<?php echo esc_attr($display_duration); ?>"
           data-display_expert="<?php echo esc_attr($display_expert); ?>"
           data-channel_name="<?php echo esc_attr($channel_name); ?>"
           data-channel_date="<?php echo esc_attr($channel_date); ?>"
           data-channel_comments="<?php echo esc_attr($channel_comments); ?>"
           data-channel_likes="<?php echo esc_attr($channel_likes); ?>"
           data-channel_view="<?php echo esc_attr($channel_view); ?>"
           data-playlist="<?php echo esc_attr($playlist); ?>"
           data-chanel="<?php echo esc_attr($channel); ?>"
           data-style="<?php echo esc_attr($style); ?>"
           data-max="<?php echo esc_attr($max); ?>"
           data-logo="<?php echo esc_attr($logo); ?>"
           data-text="<?php echo esc_attr__(' days', 'fel'); ?>"
           data-title="<?php echo esc_attr($title); ?>"
           data-order="<?php echo esc_attr($order); ?>"
           data-layout="<?php echo esc_attr($layout); ?>"
           data-key="<?php echo esc_attr($key); ?>"><?php echo esc_attr__('Load more', 'fel') ?>
    </buton>

  <?php }

  function preloader($style)
  {
    switch ($style) {
      case 'style1':
        echo '<div class="fel-ytLoader1"></div>';
        break;
      case 'style2':
        echo '<div class="fel-ytLoader2"><span></span></div>';
        break;
      case 'style3':
        echo '<div class="fel-ytLoader3"> <div class="dot"></div><div class="dot"></div><div class="dot"></div><div class="dot"></div><div class="dot"></div></div>';
        break;
      case 'style4':
        echo '<div class="fel-ytLoader4"> <div class="circle"></div><div class="circle"></div><div class="circle"></div><div class="shadow"></div><div class="shadow"></div><div class="shadow"></div></div>';
        break;
      case 'style5':
        echo '<div class="fel-ytLoader5"></div>';
        break;
      case 'style6':
        echo '<div class="fel-ytLoader6"> <div class="box"> <div></div><div></div><div></div><div></div></div><div class="box"> <div></div><div></div><div></div><div></div></div><div class="box"> <div></div><div></div><div></div><div></div></div><div class="box"> <div></div><div></div><div></div><div></div></div></div></div>';
        break;
      case 'style7':
        echo '<div class="fel-ytLoader7"> <div class="loading-flag--flag"> <div class="stripe"></div><div class="stripe"></div><div class="stripe"></div><div class="stripe"></div><div class="stripe"></div><div class="stripe"></div><div class="stripe"></div><div class="stripe"></div></div><div class="loading-flag--flag"> <div class="stripe"></div><div class="stripe"></div><div class="stripe"></div><div class="stripe"></div><div class="stripe"></div><div class="stripe"></div><div class="stripe"></div><div class="stripe"></div></div><div class="loading-flag--flag"> <div class="stripe"></div><div class="stripe"></div><div class="stripe"></div><div class="stripe"></div><div class="stripe"></div><div class="stripe"></div><div class="stripe"></div><div class="stripe"></div></div><div class="loading-flag--flag"> <div class="stripe"></div><div class="stripe"></div><div class="stripe"></div><div class="stripe"></div><div class="stripe"></div><div class="stripe"></div><div class="stripe"></div><div class="stripe"></div></div></div>';
        break;
      case 'style8':
        echo '<div class="fel-ytLoader8"></div>';
        break;
      case 'style9':
        echo '<div class="fel-ytLoader9"> <div class="blob-1"></div><div class="blob-2"></div></div>';
        break;
      case 'style10':
        echo '<div class="fel-ytLoader10"> <div class="dash uno"></div><div class="dash dos"></div><div class="dash tres"></div><div class="dash cuatro"></div></div>';
        break;
      case 'style11':
        echo '<div class="fel-ytLoader11"> <div class="item-1"></div><div class="item-2"></div><div class="item-3"></div><div class="item-4"></div><div class="item-5"></div></div>';
        break;
      case 'style12':
        echo '<div class="fel-ytLoader12"> <ul> <li></li><li></li><li></li><li></li><li></li></ul> </div>';
        break;
      case 'style13':
        echo '<div class="fel-ytLoader13"> <div></div><div></div><div></div><div></div><div></div><div></div><div></div><div></div><div></div></div>';
        break;
      case 'style14':
        echo '<div class="fel-ytLoader14"> <div class="item item-1"></div><div class="item item-2"></div><div class="item item-3"></div><div class="item item-4"></div></div>';
        break;
      case 'style15':
        echo '<div class="fel-ytLoader16"> <div id="shadow"></div><div id="box"></div></div>';
        break;
    }
  }

  function fel_calDate($date1, $date2)
  {
    $datetime1 = date_create($date1);
    $datetime2 = date_create($date2);

    $interval = date_diff($datetime1, $datetime2);

    $diff = $interval->format('%a');

    if ($diff == 0)
      return self::fel_calHour($date1, $date2);
    if ($diff <= 30)
      return $diff . esc_attr__(' days', 'fel');
    else
      return (new DateTime($date1))->format('Y-m-d');
  }

  function fel_calHour($startdate, $enddate)
  {
    $starttimestamp = strtotime($startdate);
    $endtimestamp = strtotime($enddate);
    $difference = abs($endtimestamp - $starttimestamp) / 3600;
    return $difference . esc_attr__(' hours ago', 'fel');
  }

  function fel_format($n, $precision = 1)
  {

    if ($n < 1000) {
      // Anything less than a thousand
      $n_format = number_format($n);
    } else if ($n < 1000000) {
      // Anything less than a billion
      $n_format = number_format($n / 1000, $precision) . 'k';
    } else if ($n < 1000000000) {
      // Anything less than a billion
      $n_format = number_format($n / 1000000, $precision) . 'M';
    } else {
      // At least a billion
      $n_format = number_format($n / 1000000000, $precision) . 'B';
    }

    return $n_format;

  }

  public
  function fel_getDetails($vid, $key)
  {
    //$vid - YouTube video ID. F.e. LWn28sKDWXo
    $videoDetails = file_get_contents("https://www.googleapis.com/youtube/v3/videos?id=" . esc_attr($vid) . "&part=contentDetails,statistics&key=" . esc_attr($key));
    return json_decode($videoDetails, true);
  }

  public
  function queryYT($type, $id_type, $id, $api, $part, $fields = '', $page = null, $order = '', $result = 10)
  {
    // set and retrieve response
    $page = $page ? '&pageToken=' . $this->query_meta['page_token'] : '';
    $order = ($type == 'search') ? '&order=' . esc_attr($order) : '';
    $fields = (!empty($fields)) ? '&fields=nextPageToken,pageInfo,' . esc_attr($fields) : '';
    $url = 'https://www.googleapis.com/youtube/v3/' . esc_attr($type) . '?' . esc_attr($id_type) . '=' . esc_attr($id) . '&part=' . esc_attr($part) . esc_attr($fields) . '&maxResults=' . $result . '&key=' . esc_attr($api) . esc_attr($page) . esc_attr($order);
    $response = json_decode(file_get_contents($url));

    if (isset($response) && !empty($response)) {
      $this->results = $response;
      return $response;
    }
  }

  public
  function queryYTPlaylist($type, $playlist, $key, $fields = '', $page = null, $order = '', $result = 10)
  {
    // set and retrieve response
    $page = $page ? '&pageToken=' . $this->query_meta['page_token'] : '';
    $order = ($type == 'search') ? '&order=' . esc_attr($order) : '';
    $fields = (!empty($fields)) ? '&fields=nextPageToken,pageInfo,' . esc_attr($fields) : '';
    $url = 'https://www.googleapis.com/youtube/v3/' . esc_attr($type) . '?part=snippet,contentDetails&maxResults=' . $result . '&playlistId=' . esc_attr($playlist) . '&key=' . esc_attr($key) . esc_attr($page) . esc_attr($order) . esc_attr($fields);

    $response = json_decode(wp_remote_fopen($url));

    if (isset($response) && !empty($response)) {
      $this->results = $response;
      return $response;
    }
  }

  public
  function queryYTVideos($videos, $key, $fields = '', $page = null)
  {
    // set and retrieve response
    $page = $page ? '&pageToken=' . $this->query_meta['page_token'] : '';
    $fields = (!empty($fields)) ? '&fields=nextPageToken,pageInfo,' . esc_attr($fields) : '';
    $url = 'https://www.googleapis.com/youtube/v3/videos?id=' . esc_attr($videos) . '&part=snippet,contentDetails,statistics,status&maxResults=' . count(explode(",", $videos)) . '&key=' . esc_attr($key) . esc_attr($page) . esc_attr($fields);
    $response = json_decode(wp_remote_fopen($url));

    if (isset($response) && !empty($response)) {
      $this->results = $response;
      return $response;
    }
  }
}